@@ -27,7 +27,6 @@
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-chmod-dialog.h"
 #include "gnome-cmd-chmod-component.h"
-#include "gnome-cmd-file.h"
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-user-actions.h"
 #include "utils.h"
@@ -35,12 +34,12 @@
 using namespace std;
 
 
-typedef enum
+enum ChmodRecursiveMode
 {
     CHMOD_ALL_FILES,
     CHMOD_DIRS_ONLY,
     CHMOD_MAX
-} ChmodRecursiveMode;
+};
 
 static gchar *recurse_opts[CHMOD_MAX] = {
     N_("All files"),
@@ -59,7 +58,7 @@ struct GnomeCmdChmodDialogPrivate
 };
 
 
-static GnomeCmdDialogClass *parent_class = NULL;
+G_DEFINE_TYPE (GnomeCmdChmodDialog, gnome_cmd_chmod_dialog, GNOME_CMD_TYPE_DIALOG)
 
 
 static void do_chmod (GnomeCmdFile *in, GnomeVFSFilePermissions perm, gboolean recursive, ChmodRecursiveMode mode)
@@ -69,10 +68,10 @@ static void do_chmod (GnomeCmdFile *in, GnomeVFSFilePermissions perm, gboolean r
 
     if (!(recursive && mode == CHMOD_DIRS_ONLY && in->info->type != GNOME_VFS_FILE_TYPE_DIRECTORY))
     {
-        GnomeVFSResult ret = gnome_cmd_file_chmod (in, perm);
+        GnomeVFSResult ret = in->chmod(perm);
 
         if (ret != GNOME_VFS_OK)
-            gnome_cmd_show_message (NULL, gnome_cmd_file_get_name (in), gnome_vfs_result_to_string (ret));
+            gnome_cmd_show_message (NULL, in->get_name(), gnome_vfs_result_to_string (ret));
         else
             if (!recursive)
                 return;
@@ -80,16 +79,13 @@ static void do_chmod (GnomeCmdFile *in, GnomeVFSFilePermissions perm, gboolean r
 
     if (in->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
     {
-        GnomeCmdDir *dir = GNOME_CMD_DIR (in);
-        GList *files;
+        GnomeCmdDir *dir = gnome_cmd_dir_ref (GNOME_CMD_DIR (in));
 
-        gnome_cmd_dir_ref (dir);
         gnome_cmd_dir_list_files (dir, FALSE);
-        gnome_cmd_dir_get_files (dir, &files);
 
-        for (GList *tmp = files; tmp; tmp = tmp->next)
+        for (GList *i = gnome_cmd_dir_get_files (dir); i; i = i->next)
         {
-            GnomeCmdFile *f = (GnomeCmdFile *) tmp->data;
+            GnomeCmdFile *f = (GnomeCmdFile *) i->data;
             if (!f->is_dotdot && strcmp (f->info->name, ".") != 0
                 && !GNOME_VFS_FILE_INFO_SYMLINK(f->info))
             {
@@ -103,11 +99,11 @@ static void do_chmod (GnomeCmdFile *in, GnomeVFSFilePermissions perm, gboolean r
 
 inline void do_chmod_files (GnomeCmdChmodDialog *dialog)
 {
-    for (GList *tmp = dialog->priv->files; tmp; tmp = tmp->next)
+    for (GList *i = dialog->priv->files; i; i = i->next)
     {
-        GnomeCmdFile *f = (GnomeCmdFile *) tmp->data;
+        GnomeCmdFile *f = (GnomeCmdFile *) i->data;
         gboolean recursive = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->recurse_check));
-        const gchar *mode_text = gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (dialog->priv->recurse_combo)->entry));
+        const gchar *mode_text = get_combo_text (dialog->priv->recurse_combo);
         ChmodRecursiveMode mode = strcmp (mode_text, recurse_opts[CHMOD_ALL_FILES]) == 0 ? CHMOD_ALL_FILES :
                                                                                            CHMOD_DIRS_ONLY;
 
@@ -151,40 +147,25 @@ static void on_perms_changed (GnomeCmdChmodComponent *component, GnomeCmdChmodDi
 }
 
 
-/*******************************
- * Gtk class implementation
- *******************************/
-
-static void destroy (GtkObject *object)
+static void gnome_cmd_chmod_dialog_finalize (GObject *object)
 {
     GnomeCmdChmodDialog *dialog = GNOME_CMD_CHMOD_DIALOG (object);
 
     g_free (dialog->priv);
 
-    if (GTK_OBJECT_CLASS (parent_class)->destroy)
-        (*GTK_OBJECT_CLASS (parent_class)->destroy) (object);
+    G_OBJECT_CLASS (gnome_cmd_chmod_dialog_parent_class)->finalize (object);
 }
 
 
-static void map (GtkWidget *widget)
+static void gnome_cmd_chmod_dialog_class_init (GnomeCmdChmodDialogClass *klass)
 {
-    if (GTK_WIDGET_CLASS (parent_class)->map != NULL)
-        GTK_WIDGET_CLASS (parent_class)->map (widget);
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+    object_class->finalize = gnome_cmd_chmod_dialog_finalize;
 }
 
 
-static void class_init (GnomeCmdChmodDialogClass *klass)
-{
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
-
-    parent_class = (GnomeCmdDialogClass *) gtk_type_class (gnome_cmd_dialog_get_type ());
-    object_class->destroy = destroy;
-    widget_class->map = ::map;
-}
-
-
-static void init (GnomeCmdChmodDialog *dialog)
+static void gnome_cmd_chmod_dialog_init (GnomeCmdChmodDialog *dialog)
 {
     GtkWidget *chmod_dialog = GTK_WIDGET (dialog);
     GtkWidget *vbox;
@@ -201,10 +182,8 @@ static void init (GnomeCmdChmodDialog *dialog)
 
 
     dialog->priv->chmod_component = gnome_cmd_chmod_component_new ((GnomeVFSFilePermissions) 0);
-    gtk_widget_ref (dialog->priv->chmod_component);
-    gtk_object_set_data_full (GTK_OBJECT (chmod_dialog),
-                              "chmod_component", dialog->priv->chmod_component,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (dialog->priv->chmod_component);
+    g_object_set_data_full (G_OBJECT (chmod_dialog), "chmod_component", dialog->priv->chmod_component, g_object_unref);
     gtk_widget_show (dialog->priv->chmod_component);
     gtk_box_pack_start (GTK_BOX (vbox), dialog->priv->chmod_component, TRUE, TRUE, 0);
 
@@ -225,10 +204,8 @@ static void init (GnomeCmdChmodDialog *dialog)
     gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK,
                                  GTK_SIGNAL_FUNC (on_ok), dialog);
 
-    gtk_signal_connect (GTK_OBJECT (dialog->priv->recurse_check), "toggled",
-                        GTK_SIGNAL_FUNC (on_toggle_recurse), chmod_dialog);
-    gtk_signal_connect (GTK_OBJECT (dialog->priv->chmod_component), "perms-changed",
-                        GTK_SIGNAL_FUNC (on_perms_changed), chmod_dialog);
+    g_signal_connect (dialog->priv->recurse_check, "toggled", G_CALLBACK (on_toggle_recurse), chmod_dialog);
+    g_signal_connect (dialog->priv->chmod_component, "perms-changed", G_CALLBACK (on_perms_changed), chmod_dialog);
 }
 
 
@@ -240,7 +217,7 @@ GtkWidget *gnome_cmd_chmod_dialog_new (GList *files)
 {
     g_return_val_if_fail (files != NULL, NULL);
 
-    GnomeCmdChmodDialog *dialog = (GnomeCmdChmodDialog *) gtk_type_new (gnome_cmd_chmod_dialog_get_type ());
+    GnomeCmdChmodDialog *dialog = (GnomeCmdChmodDialog *) g_object_new (GNOME_CMD_TYPE_CHMOD_DIALOG, NULL);
     dialog->priv->files = gnome_cmd_file_list_copy (files);
 
     dialog->priv->f = (GnomeCmdFile *) dialog->priv->files->data;
@@ -259,27 +236,3 @@ GtkWidget *gnome_cmd_chmod_dialog_new (GList *files)
 
     return GTK_WIDGET (dialog);
 }
-
-
-GtkType gnome_cmd_chmod_dialog_get_type ()
-{
-    static GtkType dlg_type = 0;
-
-    if (dlg_type == 0)
-    {
-        GtkTypeInfo dlg_info =
-        {
-            "GnomeCmdChmodDialog",
-            sizeof (GnomeCmdChmodDialog),
-            sizeof (GnomeCmdChmodDialogClass),
-            (GtkClassInitFunc) class_init,
-            (GtkObjectInitFunc) init,
-            /* reserved_1 */ NULL,
-            /* reserved_2 */ NULL,
-            (GtkClassInitFunc) NULL
-        };
-
-        dlg_type = gtk_type_unique (gnome_cmd_dialog_get_type (), &dlg_info);
-    }
-    return dlg_type;
-}
