@@ -15,36 +15,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
-*/
-
-/* Baobab - (C) 2005 Fabio Marzocca
-
-    baobab-remote-connect-dialog.c
-
-   Modified module from nautilus-connect-server-dialog.c
-   Released under same licence
- */
-/*
- * Nautilus
- *
- * Copyright (C) 2003 Red Hat, Inc.
- *
- * Nautilus is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
- * License, or (at your option) any later version.
- *
- * Nautilus is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
- *
- * You should have received a copy of the GNU General Public
- * License along with this program; see the file COPYING.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+    along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -60,30 +31,37 @@ using namespace std;
 #define GNOME_CMD_TYPE_CONNECT_DIALOG         (gnome_cmd_connect_dialog_get_type())
 #define GNOME_CMD_CONNECT_DIALOG(obj)         (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOME_CMD_TYPE_CONNECT_DIALOG, GnomeCmdConnectDialog))
 #define GNOME_CMD_CONNECT_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOME_CMD_TYPE_CONNECT_DIALOG, GnomeCmdConnectDialogClass))
-#define GNOME_CMD_IS_CONNECT_DIALOG(obj)      (G_TYPE_INSTANCE_CHECK_TYPE ((obj), GNOME_CMD_TYPE_CONNECT_DIALOG)
+#define GNOME_CMD_IS_CONNECT_DIALOG(obj)      (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOME_CMD_TYPE_CONNECT_DIALOG)
 
-typedef struct _GnomeCmdConnectDialog        GnomeCmdConnectDialog;
-typedef struct _GnomeCmdConnectDialogClass   GnomeCmdConnectDialogClass;
-typedef struct _GnomeCmdConnectDialogPrivate GnomeCmdConnectDialogPrivate;
 
-struct _GnomeCmdConnectDialog
+struct GnomeCmdConnectDialog
 {
     GtkDialog parent;
-    GnomeCmdConnectDialogPrivate *priv;
+
+    class Private;
+
+    Private *priv;
+
+    operator GtkWidget * () const         {  return GTK_WIDGET (this);    }
+    operator GtkWindow * () const         {  return GTK_WINDOW (this);    }
+    operator GtkDialog * () const         {  return GTK_DIALOG (this);    }
+
+    gboolean verify_uri();
 };
 
-struct _GnomeCmdConnectDialogClass
+
+struct GnomeCmdConnectDialogClass
 {
     GtkDialogClass parent_class;
 };
 
 
-struct _GnomeCmdConnectDialogPrivate
+struct GnomeCmdConnectDialog::Private
 {
     string *alias;
     string uri_str;
 
-    gboolean use_auth;
+    GnomeCmdCon::Authentication auth;
 
     GtkWidget *required_table;
     GtkWidget *optional_table;
@@ -101,16 +79,19 @@ struct _GnomeCmdConnectDialogPrivate
     GtkWidget *user_entry;
     GtkWidget *password_entry;
 
-    _GnomeCmdConnectDialogPrivate();
-    ~_GnomeCmdConnectDialogPrivate();
+    Private();
+    ~Private();
+
+    void setup_for_type();
+    void show_entry(GtkWidget *table, GtkWidget *entry, const gchar *text, gint &i);
 };
 
 
-inline _GnomeCmdConnectDialogPrivate::_GnomeCmdConnectDialogPrivate()
+inline GnomeCmdConnectDialog::Private::Private()
 {
     alias = NULL;
 
-    use_auth = FALSE;
+    auth = GnomeCmdCon::SAVE_PERMANENTLY;
 
     required_table = NULL;
     optional_table = NULL;
@@ -119,7 +100,7 @@ inline _GnomeCmdConnectDialogPrivate::_GnomeCmdConnectDialogPrivate()
     auth_check = NULL;
 
     alias_entry = gtk_entry_new ();
-    uri_entry = gtk_entry_new();
+    uri_entry = gtk_entry_new ();
     server_entry = gtk_entry_new ();
     share_entry = gtk_entry_new ();
     port_entry = gtk_entry_new ();
@@ -152,7 +133,7 @@ inline _GnomeCmdConnectDialogPrivate::_GnomeCmdConnectDialogPrivate()
 }
 
 
-inline _GnomeCmdConnectDialogPrivate::~_GnomeCmdConnectDialogPrivate()
+inline GnomeCmdConnectDialog::Private::~Private()
 {
     g_object_unref (alias_entry);
     g_object_unref (uri_entry);
@@ -168,190 +149,58 @@ inline _GnomeCmdConnectDialogPrivate::~_GnomeCmdConnectDialogPrivate()
 }
 
 
-G_DEFINE_TYPE (GnomeCmdConnectDialog, gnome_cmd_connect_dialog, GTK_TYPE_DIALOG)
-
-
-static void gnome_cmd_connect_dialog_finalize (GObject *object)
+void GnomeCmdConnectDialog::Private::setup_for_type()
 {
-    GnomeCmdConnectDialog *dialog = GNOME_CMD_CONNECT_DIALOG (object);
-
-    delete dialog->priv;
-
-    G_OBJECT_CLASS (gnome_cmd_connect_dialog_parent_class)->finalize (object);
-}
-
-
-inline gboolean verify_uri (GnomeCmdConnectDialog *dialog)
-{
-    string uri;
-    string server;
-    string share;
-    string port;
-    string folder;
-    string domain;
-    string user;
-    string password;
-
-    if (dialog->priv->uri_entry->parent)
-        stringify (uri, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->uri_entry), 0, -1));
-
-    if (dialog->priv->server_entry->parent)
-        stringify (server, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->server_entry), 0, -1));
-
-    if (dialog->priv->share_entry->parent)
-        stringify (share, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->share_entry), 0, -1));
-
-    if (dialog->priv->port_entry->parent)
-        stringify (port, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->port_entry), 0, -1));
-
-    if (dialog->priv->folder_entry->parent)
-        stringify (folder, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->folder_entry), 0, -1));
-
-    if (dialog->priv->domain_entry->parent)
-        stringify (domain, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->domain_entry), 0, -1));
-
-    if (dialog->priv->user_entry->parent)
-        stringify (user, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->user_entry), 0, -1));
-
-    if (dialog->priv->password_entry->parent)
-        stringify (password, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->password_entry), 0, -1));
-
-    int type = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
-
-    if (type!=CON_URI && server.empty())
-    {
-        gnome_cmd_show_message (GTK_WINDOW (dialog), _("You must enter a name for the server"), _("Please enter a name and try again."));
-
-        return FALSE;
-    }
-
-    dialog->priv->use_auth = type!=CON_ANON_FTP && gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->auth_check));
+    gint type = gtk_combo_box_get_active (GTK_COMBO_BOX (type_combo));
 
     if (type==CON_ANON_FTP)
-        user = "anonymous";
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (auth_check), FALSE);
 
-    gnome_cmd_con_make_uri (uri, (ConnectionMethodID) type, dialog->priv->use_auth, uri, server, share, port, folder, domain, user, password);
+    gtk_widget_set_sensitive (auth_check, type!=CON_ANON_FTP);
 
-    if (type==CON_URI && uri.empty())
-    {
-            gnome_cmd_show_message (GTK_WINDOW (dialog),
-                                    stringify(g_strdup_printf (_("\"%s\" is not a valid location"), uri.c_str())),
-                                    _("Please check the spelling and try again."));
-            return FALSE;
-    }
+    if (alias_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (required_table), alias_entry);
 
-    if (dialog->priv->alias)
-        stringify (*dialog->priv->alias, gtk_editable_get_chars (GTK_EDITABLE (dialog->priv->alias_entry), 0, -1));
+    if (uri_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (required_table), uri_entry);
 
-    dialog->priv->uri_str = uri;
+    if (server_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (required_table), server_entry);
 
-    return TRUE;
-}
+    if (share_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), share_entry);
 
+    if (port_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), port_entry);
 
-static void response_callback (GnomeCmdConnectDialog *dialog, int response_id, gpointer data)
-{
-    switch (response_id)
-    {
-        case GTK_RESPONSE_OK:
-            if (!verify_uri (dialog))
-                g_signal_stop_emission_by_name (dialog, "response");
-            break;
+    if (folder_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), folder_entry);
 
-        case GTK_RESPONSE_NONE:
-        case GTK_RESPONSE_DELETE_EVENT:
-        case GTK_RESPONSE_CANCEL:
-            break;
+    if (user_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), user_entry);
 
-        case GTK_RESPONSE_HELP:
-            gnome_cmd_help_display ("gnome-commander.xml", "gnome-commander-file-properties");
-            g_signal_stop_emission_by_name (dialog, "response");
-            break;
+    if (password_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), password_entry);
 
-        default :
-            g_assert_not_reached ();
-    }
-}
-
-
-static void gnome_cmd_connect_dialog_class_init (GnomeCmdConnectDialogClass *klass)
-{
-    GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-    object_class->finalize = gnome_cmd_connect_dialog_finalize;
-}
-
-
-inline void show_entry (GtkWidget *table, GtkWidget *entry, const gchar *text, gint &i)
-{
-    GtkWidget *label = gtk_label_new_with_mnemonic (text);
-    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
-    gtk_widget_show (label);
-    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
-
-    gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
-    gtk_widget_show (entry);
-    gtk_table_attach (GTK_TABLE (table), entry, 1, 2, i, i+1, GtkAttachOptions (GTK_FILL | GTK_EXPAND), GTK_FILL, 0, 0);
-
-    i++;
-}
-
-
-static void setup_for_type (GnomeCmdConnectDialog *dialog)
-{
-    gint type = gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
-
-    if (type==CON_ANON_FTP)
-        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->auth_check), FALSE);
-
-    gtk_widget_set_sensitive (dialog->priv->auth_check, type!=CON_ANON_FTP);
-
-    if (dialog->priv->alias_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->required_table), dialog->priv->alias_entry);
-
-    if (dialog->priv->uri_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->required_table), dialog->priv->uri_entry);
-
-    if (dialog->priv->server_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->required_table), dialog->priv->server_entry);
-
-    if (dialog->priv->share_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->share_entry);
-
-    if (dialog->priv->port_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->port_entry);
-
-    if (dialog->priv->folder_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->folder_entry);
-
-    if (dialog->priv->user_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->user_entry);
-
-    if (dialog->priv->password_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->password_entry);
-
-    if (dialog->priv->domain_entry->parent)
-        gtk_container_remove (GTK_CONTAINER (dialog->priv->optional_table), dialog->priv->domain_entry);
+    if (domain_entry->parent)
+        gtk_container_remove (GTK_CONTAINER (optional_table), domain_entry);
 
     // Destroy all labels
-    gtk_container_foreach (GTK_CONTAINER (dialog->priv->required_table), (GtkCallback) gtk_widget_destroy, NULL);
+    gtk_container_foreach (GTK_CONTAINER (required_table), (GtkCallback) gtk_widget_destroy, NULL);
 
     gint i = 1;
-    GtkWidget *table = dialog->priv->required_table;
+    GtkWidget *table = required_table;
 
     gboolean show_share, show_port, show_user, show_domain;
 
-    show_entry (table, dialog->priv->alias_entry, _("_Alias:"), i);
-
-    if (type == CON_URI)
-    {
-        show_entry (table, dialog->priv->uri_entry, _("_Location (URI):"), i);
-
-        return;
-    }
+    show_entry (table, alias_entry, _("_Alias:"), i);
 
     switch (type)
     {
+        case CON_URI:
+            show_entry (table, uri_entry, _("_Location (URI):"), i);
+            return;
+
         default:
         case CON_SSH:
         case CON_FTP:
@@ -378,7 +227,7 @@ static void setup_for_type (GnomeCmdConnectDialog *dialog)
             break;
     }
 
-    show_entry (table, dialog->priv->server_entry, _("_Server:"), i);
+    show_entry (table, server_entry, _("_Server:"), i);
 
     GtkWidget *align;
 
@@ -404,7 +253,7 @@ static void setup_for_type (GnomeCmdConnectDialog *dialog)
     gtk_widget_show (align);
 
 
-    dialog->priv->optional_table = table = gtk_table_new (1, 2, FALSE);
+    optional_table = table = gtk_table_new (1, 2, FALSE);
     gtk_table_set_row_spacings (GTK_TABLE (table), 6);
     gtk_table_set_col_spacings (GTK_TABLE (table), 12);
     gtk_widget_show (table);
@@ -413,28 +262,157 @@ static void setup_for_type (GnomeCmdConnectDialog *dialog)
     i = 0;
 
     if (show_share)
-        show_entry (table, dialog->priv->share_entry, _("S_hare:"), i);
+        show_entry (table, share_entry, _("S_hare:"), i);
 
     if (show_port)
-        show_entry (table, dialog->priv->port_entry, _("_Port:"), i);
+        show_entry (table, port_entry, _("_Port:"), i);
 
-    /* Translators: 'Dir' in the sense of 'Directory' */
-    show_entry (table, dialog->priv->folder_entry, _("_Remote dir:"), i);
+    show_entry (table, folder_entry, _("_Folder:"), i);
 
     if (show_user)
-        show_entry (table, dialog->priv->user_entry, _("_User name:"), i);
+        show_entry (table, user_entry, _("_User name:"), i);
 
-    if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->priv->auth_check)) && type!=CON_ANON_FTP)
-        show_entry (table, dialog->priv->password_entry, _("_Password:"), i);
+    if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (auth_check)) && type!=CON_ANON_FTP)
+        show_entry (table, password_entry, _("_Password:"), i);
 
     if (show_domain)
-        show_entry (table, dialog->priv->domain_entry, _("_Domain name:"), i);
+        show_entry (table, domain_entry, _("_Domain name:"), i);
+}
+
+
+inline void GnomeCmdConnectDialog::Private::show_entry(GtkWidget *table, GtkWidget *entry, const gchar *text, gint &i)
+{
+    GtkWidget *label = gtk_label_new_with_mnemonic (text);
+    gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+    gtk_widget_show (label);
+    gtk_table_attach (GTK_TABLE (table), label, 0, 1, i, i+1, GTK_FILL, GTK_FILL, 0, 0);
+
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
+    gtk_widget_show (entry);
+    gtk_table_attach (GTK_TABLE (table), entry, 1, 2, i, i+1, GtkAttachOptions (GTK_FILL | GTK_EXPAND), GTK_FILL, 0, 0);
+
+    ++i;
+}
+
+
+inline gboolean GnomeCmdConnectDialog::verify_uri()
+{
+    string uri;
+    string server;
+    string share;
+    string port;
+    string folder;
+    string domain;
+    string user;
+    string password;
+
+    if (priv->uri_entry->parent)
+        stringify (uri, gtk_editable_get_chars (GTK_EDITABLE (priv->uri_entry), 0, -1));
+
+    if (priv->server_entry->parent)
+        stringify (server, gtk_editable_get_chars (GTK_EDITABLE (priv->server_entry), 0, -1));
+
+    if (priv->share_entry->parent)
+        stringify (share, gtk_editable_get_chars (GTK_EDITABLE (priv->share_entry), 0, -1));
+
+    if (priv->port_entry->parent)
+        stringify (port, gtk_editable_get_chars (GTK_EDITABLE (priv->port_entry), 0, -1));
+
+    if (priv->folder_entry->parent)
+        stringify (folder, gtk_editable_get_chars (GTK_EDITABLE (priv->folder_entry), 0, -1));
+
+    if (priv->domain_entry->parent)
+        stringify (domain, gtk_editable_get_chars (GTK_EDITABLE (priv->domain_entry), 0, -1));
+
+    if (priv->user_entry->parent)
+        stringify (user, gtk_editable_get_chars (GTK_EDITABLE (priv->user_entry), 0, -1));
+
+    if (priv->password_entry->parent)
+        stringify (password, gtk_editable_get_chars (GTK_EDITABLE (priv->password_entry), 0, -1));
+
+    int type = gtk_combo_box_get_active (GTK_COMBO_BOX (priv->type_combo));
+
+    if (type!=CON_URI && server.empty())
+    {
+        gnome_cmd_show_message (*this, _("You must enter a name for the server"), _("Please enter a name and try again."));
+
+        return FALSE;
+    }
+
+    priv->auth = type==CON_ANON_FTP ? GnomeCmdCon::NOT_REQUIRED :
+                                      gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (priv->auth_check)) ? GnomeCmdCon::SAVE_PERMANENTLY : GnomeCmdCon::SAVE_FOR_SESSION;
+
+    if (type==CON_ANON_FTP)
+        user = "anonymous";
+
+    gnome_cmd_con_make_uri (uri, (ConnectionMethodID) type, priv->auth==GnomeCmdCon::SAVE_PERMANENTLY, uri, server, share, port, folder, domain, user, password);
+
+    if (type==CON_URI && uri.empty())
+    {
+        gnome_cmd_show_message (*this,
+                                stringify(g_strdup_printf (_("\"%s\" is not a valid location"), uri.c_str())),
+                                _("Please check spelling and try again."));
+        return FALSE;
+    }
+
+    if (priv->alias)
+        stringify (*priv->alias, gtk_editable_get_chars (GTK_EDITABLE (priv->alias_entry), 0, -1));
+
+    priv->uri_str = uri;
+
+    return TRUE;
+}
+
+
+G_DEFINE_TYPE (GnomeCmdConnectDialog, gnome_cmd_connect_dialog, GTK_TYPE_DIALOG)
+
+
+static void gnome_cmd_connect_dialog_finalize (GObject *object)
+{
+    GnomeCmdConnectDialog *dialog = GNOME_CMD_CONNECT_DIALOG (object);
+
+    delete dialog->priv;
+
+    G_OBJECT_CLASS (gnome_cmd_connect_dialog_parent_class)->finalize (object);
+}
+
+
+static void response_callback (GnomeCmdConnectDialog *dialog, int response_id, gpointer data)
+{
+    switch (response_id)
+    {
+        case GTK_RESPONSE_OK:
+            if (!dialog->verify_uri())
+                g_signal_stop_emission_by_name (dialog, "response");
+            break;
+
+        case GTK_RESPONSE_NONE:
+        case GTK_RESPONSE_DELETE_EVENT:
+        case GTK_RESPONSE_CANCEL:
+            break;
+
+        case GTK_RESPONSE_HELP:
+            gnome_cmd_help_display ("gnome-commander.xml", "gnome-commander-config-remote-connections");
+            g_signal_stop_emission_by_name (dialog, "response");
+            break;
+
+        default :
+            g_assert_not_reached ();
+    }
+}
+
+
+static void gnome_cmd_connect_dialog_class_init (GnomeCmdConnectDialogClass *klass)
+{
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+    object_class->finalize = gnome_cmd_connect_dialog_finalize;
 }
 
 
 static void dlg_changed_callback (GtkComboBox *combo_box, GnomeCmdConnectDialog *dialog)
 {
-    setup_for_type (dialog);
+    dialog->priv->setup_for_type();
 }
 
 
@@ -461,15 +439,15 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
     GtkWidget *hbox;
     GtkWidget *vbox;
 
-    dialog->priv = new GnomeCmdConnectDialogPrivate;
+    dialog->priv = new GnomeCmdConnectDialog::Private;
 
     g_return_if_fail (dialog->priv != NULL);
 
-    gtk_window_set_title (GTK_WINDOW (dialog), _("Remote Server"));
-    gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+    gtk_window_set_title (*dialog, _("Remote Server"));
+    gtk_dialog_set_has_separator (*dialog, FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
     gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 2);
-    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_window_set_resizable (*dialog, FALSE);
 
     vbox = gtk_vbox_new (FALSE, 6);
     gtk_container_set_border_width (GTK_CONTAINER (vbox), 5);
@@ -532,99 +510,92 @@ static void gnome_cmd_connect_dialog_init (GnomeCmdConnectDialog *dialog)
 
     g_signal_connect (dialog->priv->port_entry, "insert-text", G_CALLBACK (port_insert_text), NULL);
 
-    setup_for_type (dialog);
+    dialog->priv->setup_for_type();
 
-    gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+    gtk_dialog_add_buttons (*dialog,
                             GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                             GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
 
-    gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
+    gtk_dialog_set_default_response (*dialog, GTK_RESPONSE_OK);
 
     g_signal_connect (dialog, "response", G_CALLBACK (response_callback), dialog);
 }
 
 
-GnomeCmdConFtp *gnome_cmd_connect_dialog_new (gboolean has_alias)
+GnomeCmdConRemote *gnome_cmd_connect_dialog_new (gboolean has_alias)
 {
-    GtkWidget *dialog = (GtkWidget *) gtk_type_new (gnome_cmd_connect_dialog_get_type ());
+    GnomeCmdConnectDialog *dialog = (GnomeCmdConnectDialog *) g_object_new (GNOME_CMD_TYPE_CONNECT_DIALOG, NULL);
 
     g_return_val_if_fail (dialog != NULL, NULL);
 
-    GnomeCmdConnectDialog *conndlg = GNOME_CMD_CONNECT_DIALOG (dialog);
-
     if (has_alias)
-        conndlg->priv->alias = new string;
+        dialog->priv->alias = new string;
     else
-        gtk_widget_set_sensitive (conndlg->priv->alias_entry, FALSE);
+        gtk_widget_set_sensitive (dialog->priv->alias_entry, FALSE);
 
-    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), CON_SSH);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->type_combo), CON_SSH);
 
-    conndlg->priv->use_auth = gnome_cmd_data.use_gnome_auth_manager;
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (conndlg->priv->auth_check), conndlg->priv->use_auth);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->auth_check), dialog->priv->auth==GnomeCmdCon::SAVE_PERMANENTLY);
+    dialog->priv->auth = GnomeCmdCon::SAVE_PERMANENTLY;
 
-    gint response = gtk_dialog_run (GTK_DIALOG (dialog));
+    gint response = gtk_dialog_run (*dialog);
 
-    GnomeCmdConFtp *server = NULL;
+    GnomeCmdConRemote *server = NULL;
 
     if (response==GTK_RESPONSE_OK)
     {
-        const gchar *alias = conndlg->priv->alias && !conndlg->priv->alias->empty() ? conndlg->priv->alias->c_str() : NULL;
+        const gchar *alias = dialog->priv->alias && !dialog->priv->alias->empty() ? dialog->priv->alias->c_str() : NULL;
 
-        server = gnome_cmd_con_ftp_new (alias, conndlg->priv->uri_str);
+        server = gnome_cmd_con_remote_new (alias, dialog->priv->uri_str);
 
         GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-        con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (conndlg->priv->type_combo));
-        con->gnome_auth = conndlg->priv->use_auth;
+        con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
+        con->auth = dialog->priv->auth;
     }
 
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy (*dialog);
 
     return server;
 }
 
 
-gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
+gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConRemote *server)
 {
     g_return_val_if_fail (server != NULL, FALSE);
 
-    GtkWidget *dialog = gtk_widget_new (GNOME_CMD_TYPE_CONNECT_DIALOG, NULL);
+    GnomeCmdConnectDialog *dialog = (GnomeCmdConnectDialog *) gtk_widget_new (GNOME_CMD_TYPE_CONNECT_DIALOG, NULL);
 
     g_return_val_if_fail (dialog != NULL, FALSE);
 
-    GnomeCmdConnectDialog *conndlg = GNOME_CMD_CONNECT_DIALOG (dialog);
-
     GnomeCmdCon *con = GNOME_CMD_CON (server);
 
-    // Service type
-    gtk_combo_box_set_active (GTK_COMBO_BOX (conndlg->priv->type_combo), con->method);
+    gtk_combo_box_set_active (GTK_COMBO_BOX (dialog->priv->type_combo), con->method);
 
-    // Use GNOME Keyring Manager for authentication
-    conndlg->priv->use_auth = con->gnome_auth;
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (conndlg->priv->auth_check), con->gnome_auth);
+    dialog->priv->auth = con->auth;
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (dialog->priv->auth_check), con->auth==GnomeCmdCon::SAVE_PERMANENTLY);
 
-    // Alias
     if (con->alias)
     {
-        conndlg->priv->alias = new string(con->alias);
-        gtk_entry_set_text (GTK_ENTRY (conndlg->priv->alias_entry), con->alias);
+        dialog->priv->alias = new string(con->alias);
+        gtk_entry_set_text (GTK_ENTRY (dialog->priv->alias_entry), con->alias);
     }
     else
-        gtk_widget_set_sensitive (conndlg->priv->alias_entry, FALSE);
+        gtk_widget_set_sensitive (dialog->priv->alias_entry, FALSE);
 
     if (con->uri)
     {
-        conndlg->priv->uri_str = con->uri;
+        dialog->priv->uri_str = con->uri;
 
         GnomeVFSURI *uri = gnome_vfs_uri_new (con->uri);
 
         if (uri)
         {
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->uri_entry), con->uri);
+            gtk_entry_set_text (GTK_ENTRY (dialog->priv->uri_entry), con->uri);
 
-            gtk_entry_set_text (GTK_ENTRY (conndlg->priv->server_entry), gnome_vfs_uri_get_host_name (uri));
+            gtk_entry_set_text (GTK_ENTRY (dialog->priv->server_entry), gnome_vfs_uri_get_host_name (uri));
 
             const gchar *path = gnome_vfs_uri_get_path (uri);
             const gchar *user_name = gnome_vfs_uri_get_user_name (uri);
@@ -637,63 +608,63 @@ gboolean gnome_cmd_connect_dialog_edit (GnomeCmdConFtp *server)
 
                 if (g_strv_length (a) > 2)
                 {
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->share_entry), a[1]);
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), a[2]);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->share_entry), a[1]);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->folder_entry), a[2]);
                 }
                 else
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->folder_entry), path);
 
-                g_strfreev(a);
+                g_strfreev (a);
 
                 a = g_strsplit (user_name, ";", 2);
 
                 if (g_strv_length (a) > 1)
                 {
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->domain_entry), a[0]);
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), a[1]);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->domain_entry), a[0]);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->user_entry), a[1]);
                 }
                 else
-                    gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+                    gtk_entry_set_text (GTK_ENTRY (dialog->priv->user_entry), user_name);
 
-                g_strfreev(a);
+                g_strfreev (a);
             }
             else
             {
-                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->folder_entry), path);
-                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->user_entry), user_name);
+                gtk_entry_set_text (GTK_ENTRY (dialog->priv->folder_entry), path);
+                gtk_entry_set_text (GTK_ENTRY (dialog->priv->user_entry), user_name);
             }
 
             if (password)
-                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->password_entry), password);
+                gtk_entry_set_text (GTK_ENTRY (dialog->priv->password_entry), password);
 
             if (port)
-                gtk_entry_set_text (GTK_ENTRY (conndlg->priv->port_entry), stringify(port).c_str());
+                gtk_entry_set_text (GTK_ENTRY (dialog->priv->port_entry), stringify(port).c_str());
 
             gnome_vfs_uri_unref (uri);
         }
     }
 
-    gint response = gtk_dialog_run (GTK_DIALOG (dialog));
+    gint response = gtk_dialog_run (*dialog);
 
     if (response==GTK_RESPONSE_OK)
     {
-        GnomeVFSURI *uri = gnome_vfs_uri_new (conndlg->priv->uri_str.c_str());
+        GnomeVFSURI *uri = gnome_vfs_uri_new (dialog->priv->uri_str.c_str());
 
-        const gchar *alias = conndlg->priv->alias ? conndlg->priv->alias->c_str() : NULL;
-        const gchar *host = gnome_vfs_uri_get_host_name (uri);      // do not g_free !!
+        const gchar *alias = dialog->priv->alias ? dialog->priv->alias->c_str() : NULL;
+        const gchar *host = gnome_vfs_uri_get_host_name (uri);
 
         gnome_cmd_con_set_alias (con, alias);
-        gnome_cmd_con_set_uri (con, conndlg->priv->uri_str);
+        gnome_cmd_con_set_uri (con, dialog->priv->uri_str);
         gnome_cmd_con_set_host_name (con, host);
-        con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (conndlg->priv->type_combo));
-        con->gnome_auth = conndlg->priv->use_auth;
+        con->method = (ConnectionMethodID) gtk_combo_box_get_active (GTK_COMBO_BOX (dialog->priv->type_combo));
+        con->auth = dialog->priv->auth;
 
-        gnome_cmd_con_ftp_set_host_name (server, host);
+        gnome_cmd_con_remote_set_host_name (server, host);
 
         gnome_vfs_uri_unref (uri);
     }
 
-    gtk_widget_destroy (dialog);
+    gtk_widget_destroy (*dialog);
 
     return response==GTK_RESPONSE_OK;
 }
