@@ -24,6 +24,7 @@
 
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-dir.h"
+#include "gnome-cmd-con-device.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-file-props-dialog.h"
@@ -38,7 +39,7 @@
 using namespace std;
 
 
-typedef struct
+struct GnomeCmdFilePropsDialogPrivate
 {
     GtkWidget *dialog;
     GnomeCmdFile *f;
@@ -63,19 +64,7 @@ typedef struct
     GtkWidget *chown_component;
     GtkWidget *chmod_component;
 
-} GnomeCmdFilePropsDialogPrivate;
-
-
-inline const gchar *get_size_disp_string (GnomeVFSFileSize size)
-{
-    static gchar s[64];
-
-    if (gnome_cmd_data.size_disp_mode == GNOME_CMD_SIZE_DISP_MODE_POWERED)
-        return create_nice_size_str (size);
-
-    snprintf (s, sizeof (s), ngettext("%s byte","%s bytes",size), size2string (size, gnome_cmd_data.size_disp_mode));
-    return s;
-}
+};
 
 
 static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI *uri)
@@ -95,9 +84,9 @@ static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI
     if (result != GNOME_VFS_OK) return;
     if (!list) return;
 
-    for (GList *tmp = list; tmp; tmp = tmp->next)
+    for (GList *i = list; i; i = i->next)
     {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
+        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
 
         if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0)
         {
@@ -112,9 +101,9 @@ static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI
         }
     }
 
-    for (GList *tmp = list; tmp; tmp = tmp->next)
+    for (GList *i = list; i; i = i->next)
     {
-        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
+        GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
         gnome_vfs_file_info_unref (info);
     }
 
@@ -126,7 +115,7 @@ static void calc_tree_size_r (GnomeCmdFilePropsDialogPrivate *data, GnomeVFSURI
 
     g_mutex_lock (data->mutex);
     g_free (data->msg);
-    data->msg = g_strdup (get_size_disp_string (data->size));
+    data->msg = create_nice_size_str (data->size);
     g_mutex_unlock (data->mutex);
 }
 
@@ -148,7 +137,7 @@ static gboolean join_thread_func (GnomeCmdFilePropsDialogPrivate *data)
     if (data->thread)
         g_thread_join (data->thread);
 
-    gnome_cmd_file_unref (data->f);
+    data->f->unref();
     g_free (data);
 
     return FALSE;
@@ -158,7 +147,6 @@ static gboolean join_thread_func (GnomeCmdFilePropsDialogPrivate *data)
 static void on_dialog_destroy (GtkDialog *dialog, GnomeCmdFilePropsDialogPrivate *data)
 {
     data->stop = TRUE;
-
     g_timeout_add (1, (GSourceFunc) join_thread_func, data);
 }
 
@@ -194,22 +182,6 @@ static void do_calc_tree_size (GnomeCmdFilePropsDialogPrivate *data)
 }
 
 
-static void on_change_default_app (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
-{
-
-    edit_mimetypes (data->f->info->mime_type, TRUE);
-
-    GnomeVFSMimeApplication *vfs_app = gnome_vfs_mime_get_default_application (data->f->info->mime_type);
-
-    gchar *appname = vfs_app ? vfs_app->name : g_strdup (_("No default application registered"));
-
-    gtk_label_set_text (GTK_LABEL (data->app_label), appname);
-
-    if (vfs_app)
-        gnome_vfs_mime_application_free (vfs_app);
-}
-
-
 //----------------------------------------------------------------------------------
 
 
@@ -219,12 +191,12 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
 
     const gchar *filename = gtk_entry_get_text (GTK_ENTRY (data->filename_entry));
 
-    if (strcmp (filename, gnome_cmd_file_get_name (data->f)) != 0)
+    if (strcmp (filename, data->f->get_name()) != 0)
     {
-        result = gnome_cmd_file_rename (data->f, filename);
+        result = data->f->rename(filename);
 
         if (result==GNOME_VFS_OK)
-            gnome_cmd_main_win_get_fs (main_win, ACTIVE)->file_list()->focus_file(filename, TRUE);
+            main_win->fs(ACTIVE)->file_list()->focus_file(filename, TRUE);
     }
 
     if (result == GNOME_VFS_OK)
@@ -232,7 +204,7 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
         GnomeVFSFilePermissions perms = gnome_cmd_chmod_component_get_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component));
 
         if (perms != data->f->info->permissions)
-            result = gnome_cmd_file_chmod (data->f, perms);
+            result = data->f->chmod(perms);
     }
 
     if (result == GNOME_VFS_OK)
@@ -246,7 +218,7 @@ static void on_dialog_ok (GtkButton *btn, GnomeCmdFilePropsDialogPrivate *data)
             gid = -1;
 
         if (uid != -1 || gid != -1)
-            result = gnome_cmd_file_chown (data->f, uid, gid);
+            result = data->f->chown(uid,gid);
     }
 
     if (result != GNOME_VFS_OK)
@@ -272,7 +244,7 @@ static void on_copy_clipboard (GtkButton *button, GnomeCmdFilePropsDialogPrivate
     string s;
 
     for (GnomeCmdFileMetadata::METADATA_COLL::const_iterator i=data->f->metadata->begin(); i!=data->f->metadata->end(); ++i)
-        for (set<std::string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
+        for (set<string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
         {
             s += gcmd_tags_get_name(i->first);
             s += '\t';
@@ -378,7 +350,7 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, GNOME_CMD_IS_DIR (data->f) ? _("Directory name:") : _("File name:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    fname = get_utf8 (gnome_cmd_file_get_name (data->f));
+    fname = get_utf8 (data->f->get_name());
     data->filename_entry = create_entry (dialog, "filename_entry", fname);
     g_free (fname);
     table_add (table, data->filename_entry, 1, y++, (GtkAttachOptions) (GTK_FILL|GTK_EXPAND));
@@ -395,17 +367,73 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
 
     add_sep (table, y++);
 
+    if (data->f->is_local())
+    {
+        GnomeCmdDir *dir = data->f->get_parent_dir();
+        GnomeCmdCon *con = dir ? gnome_cmd_dir_get_connection (dir) : NULL;
+        gchar *location = GNOME_CMD_FILE (dir)->get_real_path();
+
+        label = create_bold_label (dialog, _("Location:"));
+        table_add (table, label, 0, y, GTK_FILL);
+
+        label = create_label (dialog, location);
+        table_add (table, label, 1, y++, GTK_FILL);
+
+        g_free (location);
+
+        label = create_bold_label (dialog, _("Volume:"));
+        table_add (table, label, 0, y, GTK_FILL);
+
+        if (GNOME_CMD_IS_CON_DEVICE (con))
+        {
+            if (GnomeVFSVolume *vol = gnome_cmd_con_device_get_vfs_volume (GNOME_CMD_CON_DEVICE (con)))
+            {
+                gchar *fs_type = gnome_vfs_volume_get_filesystem_type (vol);
+                gchar *dev_path = gnome_vfs_volume_get_device_path (vol);
+
+                gchar *s = g_strdup_printf ("%s (%s, %s)", gnome_cmd_con_get_alias (con), dev_path, fs_type);
+
+                g_free (fs_type);
+                g_free (dev_path);
+
+                label = create_label (dialog, s);
+
+                g_free (s);
+            }
+            else
+                label = create_label (dialog, gnome_cmd_con_get_alias (con));
+        }
+        else
+            label = create_label (dialog, gnome_cmd_con_get_alias (con));
+
+        table_add (table, label, 1, y++, GTK_FILL);
+
+        if (dir && gnome_cmd_con_can_show_free_space (con))
+            if (gchar *free_space = gnome_cmd_dir_get_free_space (dir))
+            {
+                label = create_bold_label (dialog, _("Free space:"));
+                table_add (table, label, 0, y, GTK_FILL);
+
+                label = create_label (dialog, free_space);
+                table_add (table, label, 1, y++, GTK_FILL);
+
+                g_free (free_space);
+            }
+
+        add_sep (table, y++);
+    }
+
     label = create_bold_label (dialog, _("Type:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mime_type_desc (data->f));
+    label = create_label (dialog, data->f->get_mime_type_desc());
     table_add (table, label, 1, y++, GTK_FILL);
 
 
     label = create_bold_label (dialog, _("MIME Type:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mime_type (data->f));
+    label = create_label (dialog, data->f->get_mime_type());
     table_add (table, label, 1, y++, GTK_FILL);
 
 
@@ -414,7 +442,7 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         label = create_bold_label (dialog, _("Opens with:"));
         table_add (table, label, 0, y, GTK_FILL);
 
-        GnomeVFSMimeApplication *vfs_app = gnome_cmd_app_get_default_application (data->f);
+        GnomeVFSMimeApplication *vfs_app = data->f->get_default_application();
 
         if (vfs_app)
         {
@@ -424,28 +452,25 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
         else
             label = create_label (dialog, _("No default application registered"));
 
-        btn = create_button_with_data (dialog, _("_Change"), GTK_SIGNAL_FUNC (on_change_default_app), data);
         hbox = create_hbox (dialog, FALSE, 6);
         gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
         label = create_label (dialog, " ");
         gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
-        gtk_box_pack_start (GTK_BOX (hbox), btn, FALSE, TRUE, 0);
         table_add (table, hbox, 1, y++, GTK_FILL);
     }
 
     add_sep (table, y++);
 
-
     label = create_bold_label (dialog, _("Modified:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_mdate (data->f, TRUE));
+    label = create_label (dialog, data->f->get_mdate(TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
 
     label = create_bold_label (dialog, _("Accessed:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, gnome_cmd_file_get_adate (data->f, TRUE));
+    label = create_label (dialog, data->f->get_adate(TRUE));
     table_add (table, label, 1, y++, GTK_FILL);
 
 
@@ -455,8 +480,10 @@ inline GtkWidget *create_properties_tab (GnomeCmdFilePropsDialogPrivate *data)
     label = create_bold_label (dialog, _("Size:"));
     table_add (table, label, 0, y, GTK_FILL);
 
-    label = create_label (dialog, get_size_disp_string (data->f->info->size));
+    gchar *s = create_nice_size_str (data->f->info->size);
+    label = create_label (dialog, s);
     table_add (table, label, 1, y++, GTK_FILL);
+    g_free (s);
     if (data->f->info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
         do_calc_tree_size (data);
 
@@ -489,10 +516,8 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
     gtk_container_add (GTK_CONTAINER (space_frame), vbox);
 
     data->chown_component = gnome_cmd_chown_component_new ();
-    gtk_widget_ref (data->chown_component);
-    gtk_object_set_data_full (GTK_OBJECT (data->dialog),
-                              "chown_component", data->chown_component,
-                              (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (data->chown_component);
+    g_object_set_data_full (G_OBJECT (data->dialog), "chown_component", data->chown_component, g_object_unref);
     gtk_widget_show (data->chown_component);
     gnome_cmd_chown_component_set (GNOME_CMD_CHOWN_COMPONENT (data->chown_component),
         data->f->info->uid, data->f->info->gid);
@@ -502,8 +527,8 @@ inline GtkWidget *create_permissions_tab (GnomeCmdFilePropsDialogPrivate *data)
 
 
     data->chmod_component = gnome_cmd_chmod_component_new ((GnomeVFSFilePermissions) 0);
-    gtk_widget_ref (data->chmod_component);
-    gtk_object_set_data_full (GTK_OBJECT (data->dialog), "chmod_component", data->chmod_component, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (data->chmod_component);
+    g_object_set_data_full (G_OBJECT (data->dialog), "chmod_component", data->chmod_component, g_object_unref);
     gtk_widget_show (data->chmod_component);
     gnome_cmd_chmod_component_set_perms (GNOME_CMD_CHMOD_COMPONENT (data->chmod_component), data->f->info->permissions);
 
@@ -558,7 +583,7 @@ static GtkTreeModel *create_and_fill_model (GnomeCmdFile *f)
                                 -1);
         }
 
-        for (set<std::string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
+        for (set<string>::const_iterator j=i->second.begin(); j!=i->second.end(); ++j)
         {
             GtkTreeIter child;
 
@@ -664,21 +689,21 @@ GtkWidget *gnome_cmd_file_props_dialog_create (GnomeCmdFile *f)
     // data->thread = 0;
 
     GtkWidget *dialog = gnome_cmd_dialog_new (_("File Properties"));
-    gtk_signal_connect (GTK_OBJECT (dialog), "destroy", (GtkSignalFunc) on_dialog_destroy, data);
+    g_signal_connect (dialog, "destroy", G_CALLBACK (on_dialog_destroy), data);
     gtk_window_set_resizable(GTK_WINDOW (dialog), TRUE);
 
     GtkWidget *notebook = gtk_notebook_new ();
 
     data->dialog = GTK_WIDGET (dialog);
     data->f = f;
-    data->uri = gnome_cmd_file_get_uri (f);
+    data->uri = f->get_uri();
     data->mutex = g_mutex_new ();
     data->msg = NULL;
     data->notebook = notebook;
-    gnome_cmd_file_ref (f);
+    f->ref();
 
-    gtk_widget_ref (notebook);
-    gtk_object_set_data_full (GTK_OBJECT (dialog), "notebook", notebook, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_ref (notebook);
+    g_object_set_data_full (G_OBJECT (dialog), "notebook", notebook, g_object_unref);
     gtk_widget_show (notebook);
     gnome_cmd_dialog_add_expanding_category (GNOME_CMD_DIALOG (dialog), notebook);
 
