@@ -28,7 +28,6 @@
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-xfer.h"
 #include "gnome-cmd-con.h"
-#include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
 #include "utils.h"
 
@@ -72,15 +71,10 @@ void gnome_cmd_prepare_move_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     gchar *dest_dir_frame_msg, *text;
     GtkWidget *label;
 
-    GList *tmp = from->file_list()->get_selected_files();
-
-    if (!tmp)
-    {
-        g_list_free (tmp);
-        return;
-    }
-
     data->dialog = GNOME_CMD_PREPARE_XFER_DIALOG (gnome_cmd_prepare_xfer_dialog_new (from, to));
+
+    g_return_if_fail (data->dialog->src_files != NULL);
+
     gtk_window_set_title (GTK_WINDOW (data->dialog), _("Move"));
     gtk_widget_ref (GTK_WIDGET (data->dialog));
 
@@ -88,43 +82,41 @@ void gnome_cmd_prepare_move_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
     // Create prepare copy specific widgets
 
     data->silent = gtk_radio_button_new_with_label (group, _("Silently"));
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (data->silent));
+    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->silent));
     gtk_widget_ref (data->silent);
-    gtk_object_set_data_full (GTK_OBJECT (data->dialog), "silent", data->silent, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_set_data_full (G_OBJECT (data->dialog), "silent", data->silent, g_object_unref);
     gtk_widget_show (data->silent);
     gtk_box_pack_start (GTK_BOX (data->dialog->left_vbox), data->silent, FALSE, FALSE, 0);
 
     data->query = gtk_radio_button_new_with_label (group, _("Query First"));
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (data->query));
+    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->query));
     gtk_widget_ref (data->query);
-    gtk_object_set_data_full (GTK_OBJECT (data->dialog), "query", data->query, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_set_data_full (G_OBJECT (data->dialog), "query", data->query, g_object_unref);
     gtk_widget_show (data->query);
     gtk_box_pack_start (GTK_BOX (data->dialog->left_vbox), data->query, FALSE, FALSE, 0);
 
     data->skip = gtk_radio_button_new_with_label (group, _("Skip All"));
-    group = gtk_radio_button_group (GTK_RADIO_BUTTON (data->skip));
+    group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (data->skip));
     gtk_widget_ref (data->skip);
-    gtk_object_set_data_full (GTK_OBJECT (data->dialog), "skip", data->skip, (GtkDestroyNotify) gtk_widget_unref);
+    g_object_set_data_full (G_OBJECT (data->dialog), "skip", data->skip, g_object_unref);
     gtk_widget_show (data->skip);
     gtk_box_pack_start (GTK_BOX (data->dialog->left_vbox), data->skip, FALSE, FALSE, 0);
 
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (g_slist_nth_data (group, gnome_cmd_data.confirm_move_overwrite)), TRUE);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (g_slist_nth_data (group, gnome_cmd_data.options.confirm_move_overwrite)), TRUE);
 
 
     // Customize prepare xfer widgets
 
     text = get_bold_text (_("Overwrite Files"));
-    label = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (data->dialog->left_vbox_frame), "label");
+    label = (GtkWidget *) g_object_get_data (G_OBJECT (data->dialog->left_vbox_frame), "label");
     gtk_label_set_markup (GTK_LABEL (label), text);
     g_free (text);
 
     text = get_bold_text (_("Options"));
-    label = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (data->dialog->right_vbox_frame), "label");
+    label = (GtkWidget *) g_object_get_data (G_OBJECT (data->dialog->right_vbox_frame), "label");
     gtk_label_set_markup (GTK_LABEL (label), text);
     g_free (text);
 
-    g_return_if_fail (data->dialog->src_files != NULL);
-
     gint num_files = g_list_length (data->dialog->src_files);
 
     if (num_files == 1)
@@ -138,16 +130,16 @@ void gnome_cmd_prepare_move_dialog_show (GnomeCmdFileSelector *from, GnomeCmdFil
         dest_dir_frame_msg = g_strdup_printf (ngettext("move %d file to","move %d files to",num_files), num_files);
 
     text = get_bold_text (dest_dir_frame_msg);
-    label = (GtkWidget *) gtk_object_get_data (GTK_OBJECT (data->dialog->dest_dir_frame), "label");
+    label = (GtkWidget *) g_object_get_data (G_OBJECT (data->dialog->dest_dir_frame), "label");
     gtk_label_set_markup (GTK_LABEL (label), text);
     g_free (text);
 
-    g_free  (dest_dir_frame_msg);
+    g_free (dest_dir_frame_msg);
 
 
     // Connect signals
 
-    gtk_signal_connect (GTK_OBJECT (data->dialog->ok_button), "clicked", GTK_SIGNAL_FUNC (on_ok), data);
+    g_signal_connect (data->dialog->ok_button, "clicked", G_CALLBACK (on_ok), data);
 
 
     // Show the dialog
