@@ -26,8 +26,6 @@
 #include "gnome-cmd-dir.h"
 #include "gnome-cmd-xfer.h"
 #include "gnome-cmd-con-list.h"
-#include "gnome-cmd-dir.h"
-#include "gnome-cmd-file.h"
 #include "gnome-cmd-file-selector.h"
 #include "gnome-cmd-main-win.h"
 #include "utils.h"
@@ -40,7 +38,7 @@ static GnomeCmdDialogClass *parent_class = NULL;
 
 inline gboolean con_device_has_path (FileSelectorID fsID, GnomeCmdCon *&dev, const gchar *user_path)
 {
-    dev = gnome_cmd_main_win_get_fs (main_win, fsID)->get_connection();
+    dev = main_win->fs(fsID)->get_connection();
 
     return GNOME_CMD_IS_CON_DEVICE (dev) &&
            g_str_has_prefix (user_path, gnome_cmd_con_device_get_mountp (GNOME_CMD_CON_DEVICE (dev)));
@@ -67,7 +65,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 
     if (user_path[0] == '/')
     {
-        if (gnome_cmd_file_selector_is_local (INACTIVE))   // hack to avoiding 'root' dir for mounted devices
+        if (main_win->fs(INACTIVE)->is_local())   // hack to avoiding 'root' dir for mounted devices
         {
             GnomeCmdCon *dev;
 
@@ -85,13 +83,13 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
     {
         if (!gnome_cmd_dir_is_local (dialog->default_dest_dir))
         {
-            const gchar *t = gnome_cmd_path_get_path (gnome_cmd_dir_get_path (dialog->default_dest_dir));
-            dest_path = g_build_path (G_DIR_SEPARATOR_S, t, user_path, NULL);
+            const gchar *t = gnome_cmd_dir_get_path (dialog->default_dest_dir)->get_path();
+            dest_path = g_build_filename (t, user_path, NULL);
         }
         else
         {
-            gchar *t = gnome_cmd_file_get_path (GNOME_CMD_FILE (dialog->src_fs->get_directory()));
-            dest_path = g_build_path (G_DIR_SEPARATOR_S, t, user_path, NULL);
+            gchar *t = GNOME_CMD_FILE (dialog->src_fs->get_directory())->get_path();
+            dest_path = g_build_filename (t, user_path, NULL);
             g_free (t);
         }
         g_free (user_path);
@@ -114,7 +112,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         {
             // There exists a directory, copy into it using the original filename
             dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, dest_path));
-            dest_fn = g_strdup (gnome_cmd_file_get_name (f));
+            dest_fn = g_strdup (f->get_name());
         }
         else
             if (res == GNOME_VFS_OK)
@@ -123,7 +121,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                 gchar *t = g_path_get_dirname (dest_path);
                 dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, t));
                 g_free (t);
-                dest_fn = g_strdup (g_basename (dest_path));
+                dest_fn = g_path_get_basename (dest_path);
             }
             else
             {
@@ -135,7 +133,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                     // yup, xfer to it
                     dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
                     g_free (parent_dir);
-                    dest_fn = g_strdup (g_basename (dest_path));
+                    dest_fn = g_path_get_basename (dest_path);
                 }
                 else
                     if (res == GNOME_VFS_OK)
@@ -158,7 +156,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                             GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, parent_dir);
                             if (mkdir_result != GNOME_VFS_OK)
                             {
-                                create_error_dialog (gnome_vfs_result_to_string (mkdir_result));
+                                gnome_cmd_show_message (*main_win, gnome_vfs_result_to_string (mkdir_result));
                                 goto bailout;
                             }
                         }
@@ -167,7 +165,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
 
                         dest_dir = gnome_cmd_dir_new (con, gnome_cmd_con_create_path (con, parent_dir));
                         g_free (parent_dir);
-                        dest_fn = g_strdup (g_basename (dest_path));
+                        dest_fn = g_path_get_basename (dest_path);
                     }
             }
     }
@@ -189,7 +187,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                 // Nothing exists, ask the user if a new directory might be suitable in the path that he specified
                 gchar *msg = g_strdup_printf (_("The directory '%s' doesn't exist, do you want to create it?"),
                                               g_basename (dest_path));
-                GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win),
+                GtkWidget *dialog = gtk_message_dialog_new (*main_win,
                                                             (GtkDialogFlags) 0,
                                                             GTK_MESSAGE_QUESTION,
                                                             GTK_BUTTONS_OK_CANCEL,
@@ -204,7 +202,7 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
                     GnomeVFSResult mkdir_result = gnome_cmd_con_mkdir (con, dest_path);
                     if (mkdir_result != GNOME_VFS_OK)
                     {
-                        create_error_dialog (gnome_vfs_result_to_string (mkdir_result));
+                        gnome_cmd_show_message (*main_win, gnome_vfs_result_to_string (mkdir_result));
                         goto bailout;
                     }
                 }
@@ -219,9 +217,9 @@ static void on_ok (GtkButton *button, GnomeCmdPrepareXferDialog *dialog)
         goto bailout;
 
     if (g_list_length (dialog->src_files) == 1)
-        DEBUG ('x', "Starting xfer the file '%s' to '%s'\n", dest_fn, gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
+        DEBUG ('x', "Starting xfer the file '%s' to '%s'\n", dest_fn, GNOME_CMD_FILE (dest_dir)->get_real_path());
     else
-        DEBUG ('x', "Starting xfer %d files to '%s'\n", g_list_length (dialog->src_files), gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dest_dir)));
+        DEBUG ('x', "Starting xfer %d files to '%s'\n", g_list_length (dialog->src_files), GNOME_CMD_FILE (dest_dir)->get_real_path());
 
 
     gnome_cmd_dir_ref (dest_dir);
@@ -293,7 +291,7 @@ static void class_init (GnomeCmdPrepareXferDialogClass *klass)
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    parent_class = (GnomeCmdDialogClass *) gtk_type_class (gnome_cmd_dialog_get_type ());
+    parent_class = (GnomeCmdDialogClass *) gtk_type_class (GNOME_CMD_TYPE_DIALOG);
 
     object_class->destroy = destroy;
     widget_class->map = ::map;
@@ -314,8 +312,7 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     gtk_box_pack_start (GTK_BOX (dest_dir_vbox), dest_dir_fileentry, FALSE, FALSE, 0);
     dialog->dest_dir_entry = gnome_file_entry_gtk_entry (GNOME_FILE_ENTRY (dest_dir_fileentry));
 
-    gtk_signal_connect (GTK_OBJECT (dialog->dest_dir_entry), "key-press-event",
-                        GTK_SIGNAL_FUNC (on_dest_dir_entry_keypressed), dialog);
+    g_signal_connect (dialog->dest_dir_entry, "key-press-event", G_CALLBACK (on_dest_dir_entry_keypressed), dialog);
 
     // options
     GtkWidget *options_hbox = create_hbox (GTK_WIDGET (dialog), TRUE, 6);
@@ -335,8 +332,8 @@ static void init (GnomeCmdPrepareXferDialog *dialog)
     dialog->cancel_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_CANCEL, NULL, NULL);
     dialog->ok_button = gnome_cmd_dialog_add_button (GNOME_CMD_DIALOG (dialog), GTK_STOCK_OK, NULL, NULL);
 
-    gtk_signal_connect_after (GTK_OBJECT (dialog->cancel_button), "clicked", GTK_SIGNAL_FUNC (on_cancel), dialog);
-    gtk_signal_connect_after (GTK_OBJECT (dialog->ok_button), "clicked", GTK_SIGNAL_FUNC (on_ok), dialog);
+    g_signal_connect_after (dialog->cancel_button, "clicked", G_CALLBACK (on_cancel), dialog);
+    g_signal_connect_after (dialog->ok_button, "clicked", G_CALLBACK (on_ok), dialog);
 
     gtk_widget_set_size_request (GTK_WIDGET (dialog), 500, -1);
 }
@@ -364,7 +361,7 @@ GtkType gnome_cmd_prepare_xfer_dialog_get_type ()
             (GtkClassInitFunc) NULL
         };
 
-        dlg_type = gtk_type_unique (gnome_cmd_dialog_get_type (), &dlg_info);
+        dlg_type = gtk_type_unique (GNOME_CMD_TYPE_DIALOG, &dlg_info);
     }
     return dlg_type;
 }
@@ -386,7 +383,7 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
     g_return_val_if_fail (to!=NULL, NULL);
 
     gchar *dest_str = NULL;
-    GnomeCmdPrepareXferDialog *dialog = (GnomeCmdPrepareXferDialog *) gtk_type_new (gnome_cmd_prepare_xfer_dialog_get_type ());
+    GnomeCmdPrepareXferDialog *dialog = (GnomeCmdPrepareXferDialog *) g_object_new (GNOME_CMD_TYPE_PREPARE_XFER_DIALOG, NULL);
 
     dialog->src_files = from->file_list()->get_selected_files();
     gnome_cmd_file_list_ref (dialog->src_files);
@@ -408,12 +405,12 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
         {
             GnomeCmdFile *f = (GnomeCmdFile *) dialog->src_files->data;
 
-            gchar *t = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dialog->default_dest_dir));
+            gchar *t = GNOME_CMD_FILE (dialog->default_dest_dir)->get_real_path();
             gchar *path = get_utf8 (t);
             gchar *fname = get_utf8 (f->info->name);
             g_free (t);
 
-            dest_str = g_build_path (G_DIR_SEPARATOR_S, path, fname, NULL);
+            dest_str = g_build_filename (path, fname, NULL);
             if (path_points_at_directory (to, dest_str))
             {
                 g_free (dest_str);
@@ -425,7 +422,7 @@ GtkWidget *gnome_cmd_prepare_xfer_dialog_new (GnomeCmdFileSelector *from, GnomeC
         }
         else
         {
-            gchar *t = gnome_cmd_file_get_real_path (GNOME_CMD_FILE (dialog->default_dest_dir));
+            gchar *t = GNOME_CMD_FILE (dialog->default_dest_dir)->get_real_path();
             dest_str = get_utf8 (t);
             g_free (t);
         }
