@@ -35,10 +35,10 @@
 using namespace std;
 
 
-#define XFER_PRIORITY 0
+#define XFER_PRIORITY GNOME_VFS_PRIORITY_DEFAULT
 
 
-typedef struct
+struct XferData
 {
     GnomeVFSXferOptions xferOptions;
     GnomeVFSAsyncHandle *handle;
@@ -74,7 +74,7 @@ typedef struct
     gboolean done;
     gboolean aborted;
 
-} XferData;
+};
 
 
 inline void free_xfer_data (XferData *data)
@@ -85,9 +85,9 @@ inline void free_xfer_data (XferData *data)
     g_list_free (data->src_uri_list);
 
     //  free the list with target uris
-    for (GList *tmp_list = data->dest_uri_list; tmp_list; tmp_list = tmp_list->next)
+    for (GList *i = data->dest_uri_list; i; i = i->next)
     {
-        GnomeVFSURI *uri = (GnomeVFSURI *) tmp_list->data;
+        GnomeVFSURI *uri = (GnomeVFSURI *) i->data;
         gnome_vfs_uri_unref (uri);
     }
 
@@ -117,7 +117,7 @@ create_xfer_data (GnomeVFSXferOptions xferOptions, GList *src_uri_list, GList *d
     data->cur_file = -1;
     data->prev_file = -1;
     data->files_total = 0;
-    data->prev_totalprog = (gfloat)0.00;
+    data->prev_totalprog = (gfloat) 0.00;
     data->first_time = TRUE;
     data->on_completed_func = on_completed_func;
     data->on_completed_data = on_completed_data;
@@ -128,6 +128,19 @@ create_xfer_data (GnomeVFSXferOptions xferOptions, GList *src_uri_list, GList *d
 }
 
 
+inline gchar *file_details(const gchar *text_uri)
+{
+    GnomeVFSFileInfo *info = gnome_vfs_file_info_new ();
+    GnomeVFSResult result = gnome_vfs_get_file_info (text_uri, info, GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+    gchar *size = create_nice_size_str (info->size);
+    gchar *details = result==GNOME_VFS_OK ? g_strdup_printf ("%s, %s", size, time2string (info->mtime, gnome_cmd_data.options.date_format)) : g_strdup ("");
+    gnome_vfs_file_info_unref (info);
+    g_free (size);
+
+    return details;
+}
+
+
 static gint async_xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgressInfo *info, XferData *data)
 {
     data->cur_phase = info->phase;
@@ -155,45 +168,61 @@ static gint async_xfer_callback (GnomeVFSAsyncHandle *handle, GnomeVFSXferProgre
 
     if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
     {
-        gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
-                                                           str_uri_basename (info->target_name);
-        gchar *fn = get_utf8 (t);
-        gchar *msg = g_strdup_printf (_("The file \"%s\" already exists.\n\nDo you want to overwrite it?\n"), fn);
+        gchar *s = gnome_cmd_dir_is_local (data->src_fl->cwd) ? gnome_vfs_get_local_path_from_uri (info->source_name) : str_uri_basename (info->source_name);
+        gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) : str_uri_basename (info->target_name);
+
+        gchar *source_filename = get_utf8 (s);
+        gchar *target_filename = get_utf8 (t);
+
+        g_free (s);
+        g_free (t);
+
+        gchar *source_details = file_details (info->source_name);
+        gchar *target_details = file_details (info->target_name);
+
+	GtkWidget *msg;
+
+        gchar *text = g_strdup_printf (_("Overwrite file:\n\n<b>%s</b>\n<span color='dimgray' size='smaller'>%s</span>\n\nWith:\n\n<b>%s</b>\n<span color='dimgray' size='smaller'>%s</span>"), target_filename, target_details, source_filename, source_details);
+
+        g_free (source_filename);
+        g_free (target_filename);
+        g_free (source_details);
+        g_free (target_details);
 
         gdk_threads_enter ();
-        gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_ERROR, msg, " ",
-                                      1, _("Abort"), _("Replace"), _("Replace All"), _("Skip"), _("Skip All"), NULL);
-        g_free (msg);
-        g_free (fn);
-        g_free (t);
+
+        gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, text, " ",
+						 1, _("Abort"), _("Replace"), _("Replace All"), _("Skip"), _("Skip All"), NULL);
+	g_free(text);
+
         data->prev_status = GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE;
         gdk_threads_leave ();
         return ret==-1 ? 0 : ret;
     }
-    else
-        if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR
-            && data->prev_status != GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
-        {
-            const gchar *error = gnome_vfs_result_to_string (info->vfs_status);
-            gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
-                                                               str_uri_basename (info->target_name);
-            gchar *fn = get_utf8 (t);
-            gchar *msg = g_strdup_printf (_("Error while copying to %s\n\n%s"), fn, error);
 
-            gdk_threads_enter ();
-            gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_ERROR, msg, _("Transfer problem"),
-                                          -1, _("Abort"), _("Retry"), _("Skip"), NULL);
-            g_free (msg);
-            g_free (fn);
-            g_free (t);
-            data->prev_status = GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR;
-            gdk_threads_leave ();
-            return ret==-1 ? 0 : ret;
-        }
+    if (info->status == GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR
+        && data->prev_status != GNOME_VFS_XFER_PROGRESS_STATUS_OVERWRITE)
+    {
+        const gchar *error = gnome_vfs_result_to_string (info->vfs_status);
+        gchar *t = gnome_cmd_dir_is_local (data->to_dir) ? gnome_vfs_get_local_path_from_uri (info->target_name) :
+                                                           str_uri_basename (info->target_name);
+        gchar *fn = get_utf8 (t);
+        gchar *msg = g_strdup_printf (_("Error while copying to %s\n\n%s"), fn, error);
+
+        gdk_threads_enter ();
+        gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_ERROR, msg, _("Transfer problem"),
+                                      -1, _("Abort"), _("Retry"), _("Skip"), NULL);
+        g_free (msg);
+        g_free (fn);
+        g_free (t);
+        data->prev_status = GNOME_VFS_XFER_PROGRESS_STATUS_VFSERROR;
+        gdk_threads_leave ();
+        return ret==-1 ? 0 : ret;
+    }
 
     if (info->phase == GNOME_VFS_XFER_PHASE_COMPLETED)
     {
-        gnome_cmd_main_win_focus_file_lists (main_win);
+        main_win->focus_file_lists();
         data->done = TRUE;
     }
 
@@ -274,9 +303,10 @@ static gboolean update_xfer_gui_func (XferData *data)
 
                 for (; data->src_files; data->src_files = data->src_files->next)
                 {
-                    GnomeVFSURI *src_uri = gnome_cmd_file_get_uri ((GnomeCmdFile *) data->src_files->data);
+                    GnomeCmdFile *f = (GnomeCmdFile *) data->src_files->data;
+                    GnomeVFSURI *src_uri = f->get_uri();
                     if (!gnome_vfs_uri_exists (src_uri))
-                        data->src_fl->remove_file((GnomeCmdFile *) data->src_files->data);
+                        data->src_fl->remove_file(f);
                     g_free (src_uri);
                 }
             }
@@ -285,7 +315,7 @@ static gboolean update_xfer_gui_func (XferData *data)
         if (data->to_dir)
         {
             gnome_cmd_dir_relist_files (data->to_dir, FALSE);
-            gnome_cmd_main_win_focus_file_lists (main_win);
+            main_win->focus_file_lists();
             gnome_cmd_dir_unref (data->to_dir);
             data->to_dir = NULL;
         }
@@ -309,7 +339,7 @@ static gboolean update_xfer_gui_func (XferData *data)
 
 inline gboolean uri_is_parent_to_dir_or_equal (GnomeVFSURI *uri, GnomeCmdDir *dir)
 {
-    GnomeVFSURI *dir_uri = gnome_cmd_file_get_uri (GNOME_CMD_FILE (dir));
+    GnomeVFSURI *dir_uri = GNOME_CMD_FILE (dir)->get_uri ();
 
     gboolean is_parent = gnome_vfs_uri_is_parent (uri, dir_uri, TRUE);
 
@@ -344,7 +374,7 @@ inline gboolean file_is_already_in_dir (GnomeVFSURI *uri, GnomeCmdDir *dir)
 {
     gchar *tmp = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
     gchar *uri_str = remove_basename (tmp);
-    gchar *dir_uri_str = gnome_cmd_file_get_uri_str (GNOME_CMD_FILE (dir));
+    gchar *dir_uri_str = GNOME_CMD_FILE (dir)->get_uri_str();
 
     gboolean ret = (strcmp (uri_str, dir_uri_str) == 0);
 
@@ -373,12 +403,12 @@ gnome_cmd_xfer_uris_start (GList *src_uri_list,
     GnomeVFSURI *src_uri, *dest_uri;
 
     // Sanity check
-    for (GList *tmp = src_uri_list; tmp; tmp = tmp->next)
+    for (GList *i = src_uri_list; i; i = i->next)
     {
-        src_uri = (GnomeVFSURI *) tmp->data;
+        src_uri = (GnomeVFSURI *) i->data;
         if (uri_is_parent_to_dir_or_equal (src_uri, to_dir))
         {
-            create_error_dialog (_("Copying a directory into itself is a bad idea.\nThe whole operation was cancelled."));
+            gnome_cmd_show_message (*main_win, _("Copying a directory into itself is a bad idea."), _("The whole operation was cancelled."));
             return;
         }
         if (file_is_already_in_dir (src_uri, to_dir))
