@@ -32,9 +32,6 @@
 #include <gtk/gtk.h>
 #include <gtk/gtktable.h>
 
-#include <libgnomeui/libgnomeui.h>
-#include <libgnome/libgnome.h>
-
 #include "libgviewer.h"
 #include "search-dlg.h"
 
@@ -154,10 +151,10 @@ GtkWidget *gviewer_window_file_view (GnomeCmdFile *f, GViewerWindowSettings *ini
 
     GtkWidget *w = gviewer_window_new ();
 
-    gviewer_window_load_file (GVIEWER_WINDOW(w), f);
+    gviewer_window_load_file (GVIEWER_WINDOW (w), f);
 
     if (initial_settings)
-        gviewer_window_set_settings(GVIEWER_WINDOW(w), initial_settings);
+        gviewer_window_set_settings(GVIEWER_WINDOW (w), initial_settings);
 
     return w;
 }
@@ -165,16 +162,16 @@ GtkWidget *gviewer_window_file_view (GnomeCmdFile *f, GViewerWindowSettings *ini
 
 void gviewer_window_load_file (GViewerWindow *obj, GnomeCmdFile *f)
 {
-    g_return_if_fail(obj!=NULL);
+    g_return_if_fail (obj!=NULL);
     g_return_if_fail (f!=NULL);
 
     g_free (obj->priv->filename);
 
     obj->priv->f = f;
-    obj->priv->filename = gnome_cmd_file_get_real_path (f);
+    obj->priv->filename = f->get_real_path();
     gviewer_load_file (obj->priv->viewer, obj->priv->filename);
 
-    gtk_window_set_title (GTK_WINDOW(obj), obj->priv->filename);
+    gtk_window_set_title (GTK_WINDOW (obj), obj->priv->filename);
 }
 
 
@@ -213,7 +210,7 @@ static void gviewer_window_class_init (GViewerWindowClass *klass)
     GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
-    parent_class = (GtkWindowClass *) gtk_type_class(gtk_window_get_type ());
+    parent_class = (GtkWindowClass *) gtk_type_class (gtk_window_get_type ());
 
     object_class->destroy = gviewer_window_destroy;
     widget_class->map = gviewer_window_map;
@@ -231,9 +228,9 @@ static void gviewer_window_init (GViewerWindow *w)
     w->priv->current_scale_index = 5;
 
     GtkWindow *win = GTK_WINDOW (w);
-    gtk_window_set_title(win, "GViewer");
+    gtk_window_set_title (win, "GViewer");
 
-    g_signal_connect(G_OBJECT (w), "key-press-event", G_CALLBACK (gviewer_window_key_pressed), NULL);
+    g_signal_connect (w, "key-press-event", G_CALLBACK (gviewer_window_key_pressed), NULL);
 
     w->priv->vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (w->priv->vbox);
@@ -243,36 +240,35 @@ static void gviewer_window_init (GViewerWindow *w)
     gtk_box_pack_start (GTK_BOX (w->priv->vbox), w->priv->menubar, FALSE, FALSE, 0);
 
     w->priv->viewer = (GViewer *) gviewer_new();
-    g_object_ref (G_OBJECT (w->priv->viewer));
+    g_object_ref (w->priv->viewer);
     gtk_widget_show (GTK_WIDGET (w->priv->viewer));
     gtk_box_pack_start (GTK_BOX (w->priv->vbox), GTK_WIDGET (w->priv->viewer), TRUE, TRUE, 0);
 
-    g_signal_connect(G_OBJECT (w->priv->viewer), "status-line-changed", G_CALLBACK (gviewer_window_status_line_changed), (gpointer) w);
+    g_signal_connect (w->priv->viewer, "status-line-changed", G_CALLBACK (gviewer_window_status_line_changed), w);
 
     w->priv->statusbar = gtk_statusbar_new ();
     gtk_widget_show (w->priv->statusbar);
     gtk_box_pack_start (GTK_BOX (w->priv->vbox), w->priv->statusbar, FALSE, FALSE, 0);
 
-    w->priv->statusbar_ctx_id  = gtk_statusbar_get_context_id(GTK_STATUSBAR(w->priv->statusbar), "info");
+    w->priv->statusbar_ctx_id  = gtk_statusbar_get_context_id (GTK_STATUSBAR (w->priv->statusbar), "info");
 
     gtk_widget_grab_focus (GTK_WIDGET (w->priv->viewer));
 
-    gtk_container_add(GTK_CONTAINER (w), w->priv->vbox);
+    gtk_container_add (GTK_CONTAINER (w), w->priv->vbox);
 }
 
 
 static void gviewer_window_status_line_changed(GViewer *obj, const gchar *status_line, GViewerWindow *wnd)
 {
-    g_return_if_fail (wnd != NULL);
     g_return_if_fail (IS_GVIEWER_WINDOW (wnd));
 
     GViewerWindow *w = GVIEWER_WINDOW (wnd);
 
     if (w->priv->status_bar_msg)
-        gtk_statusbar_pop(GTK_STATUSBAR(w->priv->statusbar), w->priv->statusbar_ctx_id);
+        gtk_statusbar_pop (GTK_STATUSBAR (w->priv->statusbar), w->priv->statusbar_ctx_id);
 
     if (status_line)
-        gtk_statusbar_push(GTK_STATUSBAR(w->priv->statusbar), w->priv->statusbar_ctx_id, status_line);
+        gtk_statusbar_push (GTK_STATUSBAR (w->priv->statusbar), w->priv->statusbar_ctx_id, status_line);
 
     w->priv->status_bar_msg = status_line!=NULL;
 }
@@ -280,8 +276,7 @@ static void gviewer_window_status_line_changed(GViewer *obj, const gchar *status
 
 void gviewer_window_set_settings(GViewerWindow *obj, /*in*/ GViewerWindowSettings *settings)
 {
-    g_return_if_fail (obj!=NULL);
-    g_return_if_fail (IS_GVIEWER_WINDOW(obj));
+    g_return_if_fail (IS_GVIEWER_WINDOW (obj));
     g_return_if_fail (settings!=NULL);
     g_return_if_fail (obj->priv->viewer!=NULL);
 
@@ -320,16 +315,15 @@ void gviewer_window_set_settings(GViewerWindow *obj, /*in*/ GViewerWindowSetting
 #if 0
     // This doesn't work because the window is not shown yet
     if (GTK_WIDGET (obj)->window)
-        gdk_window_move(GTK_WIDGET (obj)->window, settings->rect.x, settings->rect.y);
+        gdk_window_move (GTK_WIDGET (obj)->window, settings->rect.x, settings->rect.y);
 #endif
-    gtk_window_set_position(GTK_WINDOW (obj), GTK_WIN_POS_CENTER);
+    gtk_window_set_position (GTK_WINDOW (obj), GTK_WIN_POS_CENTER);
 }
 
 
 void gviewer_window_get_current_settings(GViewerWindow *obj, /* out */ GViewerWindowSettings *settings)
 {
-    g_return_if_fail (obj!=NULL);
-    g_return_if_fail (IS_GVIEWER_WINDOW(obj));
+    g_return_if_fail (IS_GVIEWER_WINDOW (obj));
     g_return_if_fail (settings!=NULL);
     g_return_if_fail (obj->priv->viewer!=NULL);
 
@@ -359,14 +353,13 @@ void gviewer_window_get_current_settings(GViewerWindow *obj, /* out */ GViewerWi
 
 static void gviewer_window_destroy (GtkObject *widget)
 {
-    g_return_if_fail (widget!= NULL);
     g_return_if_fail (IS_GVIEWER_WINDOW (widget));
 
     GViewerWindow *w = GVIEWER_WINDOW (widget);
 
     if (w->priv)
     {
-        g_object_unref (G_OBJECT (w->priv->viewer));
+        g_object_unref (w->priv->viewer);
 
         g_free (w->priv->filename);
         w->priv->filename = NULL;
@@ -382,7 +375,6 @@ static void gviewer_window_destroy (GtkObject *widget)
 
 static gboolean gviewer_window_key_pressed(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
-    g_return_val_if_fail (widget!= NULL, FALSE);
     g_return_val_if_fail (IS_GVIEWER_WINDOW (widget), FALSE);
 
     GViewerWindow *w = GVIEWER_WINDOW (widget);
@@ -414,7 +406,7 @@ static gboolean gviewer_window_key_pressed(GtkWidget *widget, GdkEventKey *event
 
             case GDK_w:
             case GDK_W:
-                gtk_widget_destroy(GTK_WIDGET (w));
+                gtk_widget_destroy (GTK_WIDGET (w));
                 return TRUE;
         }
 
@@ -477,7 +469,8 @@ enum MENUITEMTYPE
 } ;
 
 
-typedef struct {
+struct MENU_ITEM_DATA
+{
     MENUITEMTYPE menutype;
     const gchar *label;
 
@@ -495,7 +488,7 @@ typedef struct {
     GtkWidget **menu_item_widget;
 
     GSList **radio_list;
-} MENU_ITEM_DATA;
+};
 
 static GtkWidget *create_menu_item (MENUITEMTYPE type,
                                     const gchar *name,
@@ -539,7 +532,7 @@ static GtkWidget *create_menu_item (MENUITEMTYPE type,
     if (accel && keyval)
         gtk_widget_add_accelerator (menuitem, "activate", accel, keyval, (GdkModifierType) modifier, GTK_ACCEL_VISIBLE);
 
-    g_signal_connect (G_OBJECT (menuitem), "activate", callback, userdata);
+    g_signal_connect (menuitem, "activate", callback, userdata);
 
     return menuitem;
 }
@@ -555,12 +548,12 @@ static GtkWidget *create_radio_menu_item (GSList **group,
 {
     GtkWidget *menuitem = gtk_radio_menu_item_new_with_mnemonic (*group, _(name));
 
-    *group = gtk_radio_menu_item_get_group(GTK_RADIO_MENU_ITEM(menuitem));
+    *group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (menuitem));
 
     if (accel && keyval)
         gtk_widget_add_accelerator (menuitem, "activate", accel, keyval, (GdkModifierType) modifier, GTK_ACCEL_VISIBLE);
 
-    g_signal_connect (G_OBJECT (menuitem), "activate", callback, userdata);
+    g_signal_connect (menuitem, "activate", callback, userdata);
 
     gtk_widget_show (menuitem);
     gtk_container_add (GTK_CONTAINER (container), menuitem);
@@ -585,7 +578,7 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
     g_return_if_fail (menudata!=NULL);
     g_return_if_fail (container!=NULL);
 
-    while (menudata!=NULL && menudata->menutype!=MI_NONE)
+    while (menudata && menudata->menutype!=MI_NONE)
     {
         GtkWidget *item = NULL;
 
@@ -615,7 +608,7 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
 
             case MI_RADIO:
                 if (!menudata->radio_list)
-                    g_warning("radio_list field is NULL in \"%s\" menu item", menudata->label);
+                    g_warning ("radio_list field is NULL in \"%s\" menu item", menudata->label);
                 else
                 {
                     item = create_radio_menu_item(menudata->radio_list,
@@ -629,7 +622,7 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
         }
 
         if (menudata->gobj_key)
-            g_object_set_data(G_OBJECT (item), menudata->gobj_key, menudata->gobj_val);
+            g_object_set_data (G_OBJECT (item), menudata->gobj_key, menudata->gobj_val);
 
         if (menudata->menu_item_widget)
             *menudata->menu_item_widget = item;
@@ -773,27 +766,27 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
         {MI_NORMAL, _("_Rotate Clockwise"), GDK_R, GDK_CONTROL_MASK,
                 G_CALLBACK (menu_image_operation),
                 GNOME_APP_PIXMAP_FILENAME, "gnome-commander/rotate-90-16.xpm",
-                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER(ROTATE_CLOCKWISE),
+                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER (ImageRender::ROTATE_COUNTERCLOCKWISE),
                 NO_MENU_ITEM, NO_GSLIST},
         {MI_NORMAL, _("Rotate Counter Clockwis_e"), NO_KEYVAL, NO_MODIFIER,
                 G_CALLBACK (menu_image_operation),
                 GNOME_APP_PIXMAP_FILENAME, "gnome-commander/rotate-270-16.xpm",
-                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER(ROTATE_COUNTERCLOCKWISE),
+                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER (ImageRender::ROTATE_COUNTERCLOCKWISE),
                 NO_MENU_ITEM, NO_GSLIST},
         {MI_NORMAL, _("_Rotate 180\xC2\xB0"), GDK_r, GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                 G_CALLBACK (menu_image_operation),
                 GNOME_APP_PIXMAP_FILENAME, "gnome-commander/rotate-180-16.xpm",
-                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER(ROTATE_UPSIDEDOWN),
+                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER (ImageRender::ROTATE_UPSIDEDOWN),
                 NO_MENU_ITEM, NO_GSLIST},
         {MI_NORMAL, _("Flip _Vertical"), NO_KEYVAL, NO_MODIFIER,
                 G_CALLBACK (menu_image_operation),
                 GNOME_APP_PIXMAP_FILENAME, "gnome-commander/flip-vertical-16.xpm",
-                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER(FLIP_VERTICAL),
+                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER (ImageRender::FLIP_VERTICAL),
                 NO_MENU_ITEM, NO_GSLIST},
         {MI_NORMAL, _("Flip _Horizontal"), NO_KEYVAL, NO_MODIFIER,
                 G_CALLBACK (menu_image_operation),
                 GNOME_APP_PIXMAP_FILENAME, "gnome-commander/flip-horizontal-16.xpm",
-                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER(FLIP_HORIZONTAL),
+                G_OBJ_IMAGE_OP_KEY, (gpointer *) GUINT_TO_POINTER (ImageRender::FLIP_HORIZONTAL),
                 NO_MENU_ITEM, NO_GSLIST},
         {MI_NONE}
     };
@@ -888,7 +881,7 @@ static void create_menu_items (GtkWidget *container, GtkAccelGroup *accel, gpoin
 // Event Handlers
 static void menu_file_close (GtkMenuItem *item, GViewerWindow *obj)
 {
-    gtk_widget_destroy(GTK_WIDGET (obj));
+    gtk_widget_destroy (GTK_WIDGET (obj));
 }
 
 
@@ -900,7 +893,7 @@ static void menu_view_exif_information(GtkMenuItem *item, GViewerWindow *obj)
     if (gviewer_get_display_mode(obj->priv->viewer) != DISP_MODE_IMAGE)
         return;
 
-    if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (item)))
+    if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
         gviewer_window_show_metadata(obj);
     else
         gviewer_window_hide_metadata(obj);
@@ -912,14 +905,14 @@ static void menu_view_display_mode(GtkMenuItem *item, GViewerWindow *obj)
     g_return_if_fail (obj);
     g_return_if_fail (obj->priv->viewer);
 
-    if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (item)))
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
         return;
 
     VIEWERDISPLAYMODE dispmode = (VIEWERDISPLAYMODE) GPOINTER_TO_UINT (g_object_get_data(G_OBJECT (item), G_OBJ_DISPMODE_KEY));
 
     if (dispmode==DISP_MODE_IMAGE)
     {
-        if (gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (obj->priv->show_exif_menu_item)))
+        if (gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (obj->priv->show_exif_menu_item)))
             gviewer_window_show_metadata(obj);
         else
             gviewer_window_hide_metadata(obj);
@@ -930,7 +923,7 @@ static void menu_view_display_mode(GtkMenuItem *item, GViewerWindow *obj)
     gviewer_set_display_mode(obj->priv->viewer, dispmode);
     gtk_widget_grab_focus (GTK_WIDGET (obj->priv->viewer));
 
-    gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
+    gtk_widget_draw (GTK_WIDGET (obj->priv->viewer), NULL);
 }
 
 
@@ -939,17 +932,17 @@ static void menu_view_set_charset(GtkMenuItem *item, GViewerWindow *obj)
     g_return_if_fail (obj);
     g_return_if_fail (obj->priv->viewer);
 
-    if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (item)))
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
         return;
 
-    gchar *charset = (gchar *) g_object_get_data(G_OBJECT (item), G_OBJ_CHARSET_KEY);
+    gchar *charset = (gchar *) g_object_get_data (G_OBJECT (item), G_OBJ_CHARSET_KEY);
     g_return_if_fail (charset!=NULL);
 
     // ASCII is set implicitly when setting a charset
-    //gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM (w->priv->ascii_menu_item), TRUE);
+    // gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (w->priv->ascii_menu_item), TRUE);
 
     gviewer_set_encoding(obj->priv->viewer, charset);
-    gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
+    gtk_widget_draw (GTK_WIDGET (obj->priv->viewer), NULL);
 }
 
 
@@ -958,11 +951,11 @@ static void menu_image_operation(GtkMenuItem *item, GViewerWindow *obj)
     g_return_if_fail (obj);
     g_return_if_fail (obj->priv->viewer);
 
-    IMAGEOPERATION imageop = (IMAGEOPERATION) GPOINTER_TO_UINT (g_object_get_data(G_OBJECT (item), G_OBJ_IMAGE_OP_KEY));
+    ImageRender::DISPLAYMODE imageop = (ImageRender::DISPLAYMODE) GPOINTER_TO_UINT (g_object_get_data (G_OBJECT (item), G_OBJ_IMAGE_OP_KEY));
 
     gviewer_image_operation(obj->priv->viewer, imageop);
 
-    gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
+    gtk_widget_draw (GTK_WIDGET (obj->priv->viewer), NULL);
 }
 
 
@@ -1084,13 +1077,13 @@ static void menu_settings_binary_bytes_per_line(GtkMenuItem *item, GViewerWindow
     g_return_if_fail (obj);
     g_return_if_fail (obj->priv->viewer);
 
-    if (!gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM (item)))
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (item)))
         return;
 
-    int bytes_per_line = GPOINTER_TO_INT (g_object_get_data(G_OBJECT (item), G_OBJ_BYTES_PER_LINE_KEY));
+    int bytes_per_line = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (item), G_OBJ_BYTES_PER_LINE_KEY));
 
     gviewer_set_fixed_limit(obj->priv->viewer, bytes_per_line);
-    gtk_widget_draw(GTK_WIDGET (obj->priv->viewer), NULL);
+    gtk_widget_draw (GTK_WIDGET (obj->priv->viewer), NULL);
 }
 
 
@@ -1099,7 +1092,7 @@ static void menu_edit_copy(GtkMenuItem *item, GViewerWindow *obj)
     g_return_if_fail (obj);
     g_return_if_fail (obj->priv->viewer);
 
-    gviewer_copy_selection(obj->priv->viewer);
+    gviewer_copy_selection(item, obj->priv->viewer);
 }
 
 
@@ -1178,7 +1171,7 @@ static void menu_edit_find(GtkMenuItem *item, GViewerWindow *obj)
     {
         // Hex Search
         guint buflen;
-        guint8 *buffer = gviewer_search_dlg_get_search_hex_buffer (srch_dlg, &buflen);
+        guint8 *buffer = gviewer_search_dlg_get_search_hex_buffer (srch_dlg, buflen);
 
         g_return_if_fail (buffer!=NULL);
 
@@ -1192,7 +1185,7 @@ static void menu_edit_find(GtkMenuItem *item, GViewerWindow *obj)
         g_free (buffer);
     }
 
-    gtk_widget_destroy(w);
+    gtk_widget_destroy (w);
 
 
     // call  "find_next" to actually do the search
@@ -1254,29 +1247,29 @@ void gviewer_window_load_settings(/* out */ GViewerWindowSettings *settings)
 {
     g_return_if_fail (settings!=NULL);
 
-    gchar *temp = gviewer_get_string(GVIEWER_DEFAULT_PATH_PREFIX "charset", "ASCII");
+    gchar *temp = gviewer_get_string (GVIEWER_DEFAULT_PATH_PREFIX "charset", "ASCII");
     strncpy(settings->charset, temp, sizeof(settings->charset));
     g_free (temp);
 
-    temp = gviewer_get_string(GVIEWER_DEFAULT_PATH_PREFIX "fixed_font_name", "Monospace");
+    temp = gviewer_get_string (GVIEWER_DEFAULT_PATH_PREFIX "fixed_font_name", "Monospace");
     strncpy(settings->fixed_font_name, temp, sizeof(settings->fixed_font_name));
     g_free (temp);
 
-    temp = gviewer_get_string(GVIEWER_DEFAULT_PATH_PREFIX "variable_font_name", "Sans");
+    temp = gviewer_get_string (GVIEWER_DEFAULT_PATH_PREFIX "variable_font_name", "Sans");
     strncpy(settings->variable_font_name, temp, sizeof(settings->variable_font_name));
     g_free (temp);
 
-    settings->hex_decimal_offset = gviewer_get_bool(GVIEWER_DEFAULT_PATH_PREFIX "hex_offset_display", TRUE);
-    settings->wrap_mode = gviewer_get_bool(GVIEWER_DEFAULT_PATH_PREFIX "wrap_mode", TRUE);
+    settings->hex_decimal_offset = gviewer_get_bool (GVIEWER_DEFAULT_PATH_PREFIX "hex_offset_display", TRUE);
+    settings->wrap_mode = gviewer_get_bool (GVIEWER_DEFAULT_PATH_PREFIX "wrap_mode", TRUE);
 
-    settings->font_size = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "font_size", 12);
-    settings->tab_size = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "tab_size ", 8);
-    settings->binary_bytes_per_line = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "binary_bytes_per_line", 80);
+    settings->font_size = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "font_size", 12);
+    settings->tab_size = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "tab_size ", 8);
+    settings->binary_bytes_per_line = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "binary_bytes_per_line", 80);
 
-    settings->rect.x = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "x", -2);
-    settings->rect.y = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "y", -2);
-    settings->rect.width = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "width", -1);
-    settings->rect.height = gviewer_get_int(GVIEWER_DEFAULT_PATH_PREFIX "height", -1);
+    settings->rect.x = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "x", -2);
+    settings->rect.y = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "y", -2);
+    settings->rect.width = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "width", -1);
+    settings->rect.height = gviewer_get_int (GVIEWER_DEFAULT_PATH_PREFIX "height", -1);
 }
 
 
@@ -1289,23 +1282,23 @@ static void menu_settings_save_settings(GtkMenuItem *item, GViewerWindow *obj)
 
     gviewer_window_get_current_settings(obj, &settings);
 
-    gnome_config_set_string(GVIEWER_DEFAULT_PATH_PREFIX "charset", settings.charset);
-    gnome_config_set_string(GVIEWER_DEFAULT_PATH_PREFIX "fixed_font_name", settings.fixed_font_name);
-    gnome_config_set_string(GVIEWER_DEFAULT_PATH_PREFIX "variable_font_name", settings.variable_font_name);
+    gnome_config_set_string (GVIEWER_DEFAULT_PATH_PREFIX "charset", settings.charset);
+    gnome_config_set_string (GVIEWER_DEFAULT_PATH_PREFIX "fixed_font_name", settings.fixed_font_name);
+    gnome_config_set_string (GVIEWER_DEFAULT_PATH_PREFIX "variable_font_name", settings.variable_font_name);
 
-    gnome_config_set_bool(GVIEWER_DEFAULT_PATH_PREFIX "hex_offset_display", settings.hex_decimal_offset);
-    gnome_config_set_bool(GVIEWER_DEFAULT_PATH_PREFIX "wrap_mode", settings.wrap_mode);
+    gnome_config_set_bool (GVIEWER_DEFAULT_PATH_PREFIX "hex_offset_display", settings.hex_decimal_offset);
+    gnome_config_set_bool (GVIEWER_DEFAULT_PATH_PREFIX "wrap_mode", settings.wrap_mode);
 
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "font_size", settings.font_size);
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "tab_size ", settings.tab_size);
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "binary_bytes_per_line", settings.binary_bytes_per_line);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "font_size", settings.font_size);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "tab_size ", settings.tab_size);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "binary_bytes_per_line", settings.binary_bytes_per_line);
+ 
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "x", settings.rect.x);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "y", settings.rect.y);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "width", settings.rect.width);
+    gnome_config_set_int (GVIEWER_DEFAULT_PATH_PREFIX "height", settings.rect.height);
 
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "x", settings.rect.x);
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "y", settings.rect.y);
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "width", settings.rect.width);
-    gnome_config_set_int(GVIEWER_DEFAULT_PATH_PREFIX "height", settings.rect.height);
-
-    gnome_config_sync();
+    gnome_config_sync ();
 }
 
 
