@@ -24,6 +24,7 @@
 #include <errno.h>
 #include <dirent.h>
 #include <fnmatch.h>
+#include <stdlib.h>
 
 #include <set>
 
@@ -39,12 +40,12 @@
 using namespace std;
 
 
-typedef struct
+struct TmpDlData
 {
     GnomeCmdFile *f;
     GtkWidget *dialog;
     gpointer *args;
-} TmpDlData;
+};
 
 #ifdef HAVE_LOCALE_H
 extern struct lconv *locale_information;
@@ -60,7 +61,7 @@ static gchar *tmp_file_dir = NULL;
 /**
  * The already reserved debug flags:
  * --------------------------------
- * a: user actions debugging
+ * a: set all debug flags
  * c: file and directory counting
  * d: directory ref-counting
  * f: file ref-counting
@@ -73,6 +74,7 @@ static gchar *tmp_file_dir = NULL;
  * p: python plugins
  * s: smb network browser
  * t: metadata tags
+ * u: user actions debugging
  * v: internal viewer
  * w: widget_lookup
  * y: brief mime-based imageload
@@ -93,18 +95,6 @@ void DEBUG (gchar flag, const gchar *format, ...)
 }
 
 
-void warn_print (const gchar *fmt, ...)
-{
-    va_list     argptr;
-    char        string[1024];
-
-    va_start (argptr,fmt);
-    vsnprintf (string,sizeof(string),fmt,argptr);
-    va_end (argptr);
-    g_printerr("WARNING: %s", string);
-}
-
-
 void run_command_indir (const gchar *in_command, const gchar *dir, gboolean term)
 {
     gchar *command;
@@ -122,7 +112,7 @@ void run_command_indir (const gchar *in_command, const gchar *dir, gboolean term
         else
             arg = g_shell_quote (in_command);
 
-        command = g_strdup_printf (gnome_cmd_data.get_term(), arg);
+        command = g_strdup_printf (gnome_cmd_data.options.term, arg);
 
         g_free (arg);
     }
@@ -161,7 +151,7 @@ static gboolean delete_event_callback (gpointer data, gpointer user_data)
 {
     g_return_val_if_fail (GTK_IS_DIALOG (data), FALSE);
 
-    gtk_signal_emit_stop_by_name (GTK_OBJECT (data), "delete-event");
+    g_signal_stop_emission_by_name (data, "delete-event");
 
     return TRUE;
 }
@@ -194,7 +184,9 @@ gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
     button_titles = convert_varargs_to_name_array (button_title_args);
     va_end (button_title_args);
 
-    dialog = gtk_message_dialog_new (GTK_WINDOW (main_win), GTK_DIALOG_MODAL, msg_type, GTK_BUTTONS_NONE, "%s", text);
+    dialog = gtk_message_dialog_new (*main_win, GTK_DIALOG_MODAL, msg_type, GTK_BUTTONS_NONE, NULL);
+    gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (dialog), text);
+
     if (title)
         gtk_window_set_title (GTK_WINDOW (dialog), title);
 
@@ -204,13 +196,13 @@ gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
     g_free (button_titles);
 
     if (def_response>=0)
-        gtk_dialog_set_default_response(GTK_DIALOG (dialog), def_response);
+        gtk_dialog_set_default_response (GTK_DIALOG (dialog), def_response);
 
     // Allow close.
     if (ignore_close_box)
-        gtk_signal_connect (GTK_OBJECT (dialog), "delete-event", GTK_SIGNAL_FUNC (delete_event_callback), NULL);
+        g_signal_connect (dialog, "delete-event", G_CALLBACK (delete_event_callback), NULL);
     else
-        gtk_signal_connect (GTK_OBJECT (dialog), "key-press-event", GTK_SIGNAL_FUNC (on_run_dialog_keypress), dialog);
+        g_signal_connect (dialog, "key-press-event", G_CALLBACK (on_run_dialog_keypress), dialog);
 
     gtk_window_set_wmclass (GTK_WINDOW (dialog), "dialog", "Eel");
 
@@ -222,12 +214,11 @@ gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
     }
     while (ignore_close_box && result == GTK_RESPONSE_DELETE_EVENT);
 
-    gtk_widget_destroy(dialog);
+    gtk_widget_destroy (dialog);
 
     return result;
 }
 
-
 gchar *str_uri_basename (const gchar *uri)
 {
     if (!uri)
@@ -298,7 +289,7 @@ const gchar *name2string (gchar *filename, gchar *buf, guint max)
 
 const gchar *perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
-    switch (gnome_cmd_data.perm_disp_mode)
+    switch (gnome_cmd_data.options.perm_disp_mode)
     {
         case GNOME_CMD_PERM_DISP_MODE_TEXT:
             return perm2textstring (p, buf, max);
@@ -433,10 +424,8 @@ const gchar *time2string (time_t t, const gchar *date_format)
 
 inline void no_mime_app_found_error (gchar *mime_type)
 {
-    gchar *msg;
-
-    msg = g_strdup_printf (_("No default application found for the MIME type %s.\nOpen the \"File types and programs\" page in the Control Center to add one."), mime_type);
-    create_error_dialog (msg);
+    gchar *msg = g_strdup_printf (_("No default application found for the MIME type %s."), mime_type);
+    gnome_cmd_show_message (NULL, msg, "Open the \"File types and programs\" page in the Control Center to add one.");
     g_free (msg);
 }
 
@@ -466,17 +455,15 @@ static void on_tmp_download_response (GtkWidget *w, gint id, TmpDlData *dldata)
 {
     if (id == GTK_RESPONSE_YES)
     {
-        gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (dldata->f));
+        gchar *path_str = get_temp_download_filepath (dldata->f->get_name());
 
         if (!path_str) return;
 
         dldata->args[1] = (gpointer) path_str;
 
-        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (dldata->f));
-        GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
-        GnomeCmdCon *con = get_home_con ();
-        GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (con, path);
-        gtk_object_destroy (GTK_OBJECT (path));
+        GnomeVFSURI *src_uri = gnome_vfs_uri_dup (dldata->f->get_uri());
+        GnomeCmdPlainPath path(path_str);
+        GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
 
         gnome_cmd_xfer_tmp_download (src_uri,
                                      dest_uri,
@@ -510,13 +497,13 @@ void mime_exec_single (GnomeCmdFile *f)
 
     // Check if the file is a binary executable that lacks the executable bit
 
-    if (!gnome_cmd_file_is_executable (f))
+    if (!f->is_executable())
     {
-        if (gnome_cmd_file_has_mime_type (f, "application/x-executable") || gnome_cmd_file_has_mime_type (f, "application/x-executable-binary"))
+        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
         {
             gchar *fname = get_utf8 (f->info->name);
             gchar *msg = g_strdup_printf (_("\"%s\" seems to be a binary executable file but it lacks the executable bit. Do you want to set it and then run the file?"), fname);
-            gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg,
+            gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg,
                                           _("Make Executable?"),
                                           -1, _("Cancel"), _("OK"), NULL);
             g_free (fname);
@@ -524,7 +511,7 @@ void mime_exec_single (GnomeCmdFile *f)
 
             if (ret != 1)  return;  else
             {
-                GnomeVFSResult result = gnome_cmd_file_chmod (f, (GnomeVFSFilePermissions) (f->info->permissions|GNOME_VFS_PERM_USER_EXEC));
+                GnomeVFSResult result = f->chmod((GnomeVFSFilePermissions) (f->info->permissions|GNOME_VFS_PERM_USER_EXEC));
                 if (result != GNOME_VFS_OK)
                     return;
             }
@@ -533,19 +520,19 @@ void mime_exec_single (GnomeCmdFile *f)
 
     // If the file is executable but not a binary file, check if the user wants to exec it or open it
 
-    if (gnome_cmd_file_is_executable (f))
+    if (f->is_executable())
     {
-        if (gnome_cmd_file_has_mime_type (f, "application/x-executable") || gnome_cmd_file_has_mime_type (f, "application/x-executable-binary") )
+        if (f->has_mime_type("application/x-executable") || f->has_mime_type("application/x-executable-binary"))
         {
-            gnome_cmd_file_execute (f);
+            f->execute();
             return;
         }
         else
-            if (gnome_cmd_file_mime_begins_with (f, "text/"))
+            if (f->mime_begins_with("text/"))
             {
                 gchar *fname = get_utf8 (f->info->name);
                 gchar *msg = g_strdup_printf (_("\"%s\" is an executable text file. Do you want to run it, or display its contents?"), fname);
-                gint ret = run_simple_dialog (GTK_WIDGET (main_win), FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
+                gint ret = run_simple_dialog (*main_win, FALSE, GTK_MESSAGE_QUESTION, msg, _("Run or Display"),
                                               -1, _("Cancel"), _("Display"), _("Run"), NULL);
                 g_free (fname);
                 g_free (msg);
@@ -553,7 +540,7 @@ void mime_exec_single (GnomeCmdFile *f)
                 if (ret != 1)
                 {
                     if (ret == 2)
-                        gnome_cmd_file_execute (f);
+                        f->execute();
                     return;
                 }
             }
@@ -571,27 +558,26 @@ void mime_exec_single (GnomeCmdFile *f)
 
     args = g_new0 (gpointer, 3);
 
-    if (gnome_cmd_file_is_local (f))
+    if (f->is_local())
     {
         args[0] = (gpointer) app;
-        args[1] = (gpointer) g_strdup (gnome_cmd_file_get_real_path (f));
+        args[1] = (gpointer) f->get_real_path();
         args[2] = (gpointer) g_path_get_dirname ((gchar *) args[1]);            // set exec dir for local files
         do_mime_exec_single (args);
     }
     else
     {
-        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.honor_expect_uris)
+        if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
         {
             args[0] = (gpointer) app;
-            args[1] = (gpointer) g_strdup (gnome_cmd_file_get_uri_str (f));
+            args[1] = (gpointer) f->get_uri_str();
             // args[2] is NULL here (don't set exec dir for remote files)
             do_mime_exec_single (args);
         }
         else
         {
             gchar *msg = g_strdup_printf (_("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?"), gnome_cmd_app_get_name (app));
-            GtkWidget *dialog = gtk_message_dialog_new (GTK_WINDOW (main_win), GTK_DIALOG_MODAL,
-                                                        GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", msg);
+            GtkWidget *dialog = gtk_message_dialog_new (*main_win, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", msg);
             TmpDlData *dldata = g_new0 (TmpDlData, 1);
             args[0] = (gpointer) app;
             // args[2] is NULL here (don't set exec dir for temporarily downloaded files)
@@ -599,7 +585,7 @@ void mime_exec_single (GnomeCmdFile *f)
             dldata->dialog = dialog;
             dldata->args = args;
 
-            gtk_signal_connect (GTK_OBJECT (dialog), "response", GTK_SIGNAL_FUNC (on_tmp_download_response), dldata);
+            g_signal_connect (dialog, "response", G_CALLBACK (on_tmp_download_response), dldata);
             gtk_widget_show (dialog);
             g_free (msg);
         }
@@ -658,14 +644,14 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
     {
         GnomeCmdFile *f = (GnomeCmdFile *) files->data;
 
-        if (gnome_vfs_uri_is_local (gnome_cmd_file_get_uri (f)))
-            local_files = g_list_append (local_files, g_strdup (gnome_cmd_file_get_real_path (f)));
+        if (gnome_vfs_uri_is_local (f->get_uri()))
+            local_files = g_list_append (local_files, f->get_real_path());
         else
         {
             ++no_of_remote_files;
-            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.honor_expect_uris)
+            if (gnome_cmd_app_get_handles_uris (app) && gnome_cmd_data.options.honor_expect_uris)
             {
-                local_files = g_list_append (local_files,  g_strdup (gnome_cmd_file_get_uri_str (f)));
+                local_files = g_list_append (local_files,  f->get_uri_str());
             }
             else
             {
@@ -674,20 +660,19 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
                     gchar *msg = g_strdup_printf (ngettext("%s does not know how to open remote file. Do you want to download the file to a temporary location and then open it?",
                                                            "%s does not know how to open remote files. Do you want to download the files to a temporary location and then open them?", no_of_remote_files),
                                                   gnome_cmd_app_get_name (app));
-                    retid = run_simple_dialog (GTK_WIDGET (main_win), TRUE, GTK_MESSAGE_QUESTION, msg, "", -1, _("No"), _("Yes"), NULL);
+                    retid = run_simple_dialog (*main_win, TRUE, GTK_MESSAGE_QUESTION, msg, "", -1, _("No"), _("Yes"), NULL);
                     asked = TRUE;
                 }
 
                 if (retid==1)
                 {
-                    gchar *path_str = get_temp_download_filepath (gnome_cmd_file_get_name (f));
+                    gchar *path_str = get_temp_download_filepath (f->get_name());
 
                     if (!path_str) return;
 
-                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (gnome_cmd_file_get_uri (f));
-                    GnomeCmdPath *path = gnome_cmd_plain_path_new (path_str);
-                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), path);
-                    gtk_object_destroy (GTK_OBJECT (path));
+                    GnomeVFSURI *src_uri = gnome_vfs_uri_dup (f->get_uri());
+                    GnomeCmdPlainPath path(path_str);
+                    GnomeVFSURI *dest_uri = gnome_cmd_con_create_uri (get_home_con (), &path);
 
                     src_uri_list = g_list_append (src_uri_list, src_uri);
                     dest_uri_list = g_list_append (dest_uri_list, dest_uri);
@@ -759,12 +744,9 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
     if (!dir_uri)
         return -1;
 
-    gchar *dir_uri_str;
+    gchar *dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
 
-    dir_uri_str = gnome_vfs_uri_to_string (dir_uri, GNOME_VFS_URI_HIDE_NONE);
-
-    if (!dir_uri_str)
-        return -1;
+    g_return_val_if_fail (dir_uri_str != NULL, -1);
 
     GList *list = NULL;
     GnomeVFSFileSize size = 0;
@@ -773,9 +755,9 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
 
     if (result==GNOME_VFS_OK && list)
     {
-        for (GList *tmp = list; tmp; tmp = tmp->next)
+        for (GList *i = list; i; i = i->next)
         {
-            GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) tmp->data;
+            GnomeVFSFileInfo *info = (GnomeVFSFileInfo *) i->data;
             if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0)
             {
                 if (info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
@@ -789,8 +771,8 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
             }
         }
 
-        for (GList *tmp = list; tmp; tmp = tmp->next)
-            gnome_vfs_file_info_unref ((GnomeVFSFileInfo *) tmp->data);
+        for (GList *i = list; i; i = i->next)
+            gnome_vfs_file_info_unref ((GnomeVFSFileInfo *) i->data);
 
         g_list_free (list);
     }
@@ -831,21 +813,19 @@ GList *string_history_add (GList *in, const gchar *value, guint maxsize)
 }
 
 
-const gchar *create_nice_size_str (GnomeVFSFileSize size)
+gchar *create_nice_size_str (GnomeVFSFileSize size)
 {
-    static gchar str1[64];
-    const gchar *s1 = size2string (size, GNOME_CMD_SIZE_DISP_MODE_GROUPED);
-    snprintf (str1, sizeof (str1), ngettext("%s byte","%s bytes",size), s1);
+    GString *s = g_string_sized_new (64);
 
-    if (size >= 1000)
+    if (gnome_cmd_data.options.size_disp_mode==GNOME_CMD_SIZE_DISP_MODE_POWERED && size>=1000)
     {
-        static gchar str2[128];
-        const gchar *s2 = size2string (size, GNOME_CMD_SIZE_DISP_MODE_POWERED);
-        snprintf (str2, sizeof (str2), "%s (%s)", s2, str1);
-        return str2;
+        g_string_printf (s, "%s", size2string (size, GNOME_CMD_SIZE_DISP_MODE_POWERED));
+        g_string_append_printf (s, ngettext("(%sbyte)","(%sbytes)",size), size2string (size, GNOME_CMD_SIZE_DISP_MODE_GROUPED));
     }
+    else
+        g_string_printf (s, ngettext("%sbyte","%sbytes",size), size2string (size, GNOME_CMD_SIZE_DISP_MODE_GROUPED));
 
-    return str1;
+    return g_string_free (s, FALSE);
 }
 
 
@@ -873,7 +853,7 @@ GtkWidget *create_styled_button (const gchar *text)
     GtkWidget *w = text ? gtk_button_new_with_label (text) : gtk_button_new ();
 
     gtk_button_set_relief (GTK_BUTTON (w), gnome_cmd_data.button_relief);
-    gtk_widget_ref (w);
+    g_object_ref (w);
     gtk_widget_show (w);
 
     return w;
@@ -889,8 +869,8 @@ GtkWidget *create_styled_pixmap_button (const gchar *text, GnomeCmdPixmap *pm)
     GtkWidget *label = NULL;
     GtkWidget *pixmap = NULL;
 
-    gtk_object_set_data_full (GTK_OBJECT (btn), "hbox", hbox, (GtkDestroyNotify) gtk_widget_unref);
-    gtk_widget_ref (hbox);
+    g_object_set_data_full (G_OBJECT (btn), "hbox", hbox, g_object_unref);
+    g_object_ref (hbox);
     gtk_widget_show (hbox);
 
     if (pm)
@@ -898,9 +878,8 @@ GtkWidget *create_styled_pixmap_button (const gchar *text, GnomeCmdPixmap *pm)
         pixmap = gtk_pixmap_new (pm->pixmap, pm->mask);
         if (pixmap)
         {
-            gtk_widget_ref (pixmap);
-            gtk_object_set_data_full (GTK_OBJECT (btn), "pixmap", pixmap,
-                                      (GtkDestroyNotify) gtk_widget_unref);
+            g_object_ref (pixmap);
+            g_object_set_data_full (G_OBJECT (btn), "pixmap", pixmap, g_object_unref);
             gtk_widget_show (pixmap);
         }
     }
@@ -908,9 +887,8 @@ GtkWidget *create_styled_pixmap_button (const gchar *text, GnomeCmdPixmap *pm)
     if (text)
     {
         label = gtk_label_new (text);
-        gtk_widget_ref (label);
-        gtk_object_set_data_full (GTK_OBJECT (btn), "label", label,
-                                  (GtkDestroyNotify) gtk_widget_unref);
+        g_object_ref (label);
+        g_object_set_data_full (G_OBJECT (btn), "label", label, g_object_unref);
         gtk_widget_show (label);
     }
 
@@ -944,13 +922,13 @@ void set_cursor_busy_for_widget (GtkWidget *widget)
 
 void set_cursor_busy ()
 {
-    set_cursor_busy_for_widget (GTK_WIDGET (main_win));
+    set_cursor_busy_for_widget (*main_win);
 }
 
 
 void set_cursor_default ()
 {
-    set_cursor_default_for_widget (GTK_WIDGET (main_win));
+    set_cursor_default_for_widget (*main_win);
 }
 
 
@@ -961,7 +939,7 @@ GList *app_get_linked_libs (GnomeCmdFile *f)
     gchar *s;
     gchar tmp[256];
 
-    gchar *arg = g_shell_quote (gnome_cmd_file_get_real_path (f));
+    gchar *arg = g_shell_quote (f->get_real_path());
     gchar *cmd = g_strdup_printf ("ldd %s", arg);
     g_free (arg);
     FILE *fd = popen (cmd, "r");
@@ -997,9 +975,9 @@ gboolean app_needs_terminal (GnomeCmdFile *f)
     GList *libs = app_get_linked_libs (f);
     if  (!libs) return FALSE;
 
-    for (GList *tmp = libs; tmp; tmp = tmp->next)
+    for (GList *i = libs; i; i = i->next)
     {
-        gchar *lib = (gchar *) tmp->data;
+        gchar *lib = (gchar *) i->data;
         lib = g_strstrip (lib);
         if (g_str_has_prefix (lib, "libX11"))
         {
@@ -1028,24 +1006,21 @@ gchar *get_temp_download_filepath (const gchar *fname)
         {
             g_free (tmp_file_dir_template);
 
-            create_error_dialog (
-                _("Failed to create a directory in which to store temporary files.\nError message: %s\n"),
-                strerror (errno));
+            gnome_cmd_show_message (NULL, _("Failed to create a directory in which to store temporary files."), strerror (errno));
+
             return NULL;
         }
     }
 
-    return g_build_path (G_DIR_SEPARATOR_S, tmp_dir, tmp_file_dir, fname, NULL);
+    return g_build_filename (tmp_dir, tmp_file_dir, fname, NULL);
 }
 
 
 void remove_temp_download_dir ()
 {
-    const gchar *tmp_dir = g_get_tmp_dir ();
-
     if (tmp_file_dir)
     {
-        gchar *path = g_build_path (G_DIR_SEPARATOR_S, tmp_dir, tmp_file_dir, NULL);
+        gchar *path = g_build_filename (g_get_tmp_dir (), tmp_file_dir, NULL);
         gchar *command = g_strdup_printf ("rm -rf %s", path);
         g_free (path);
         system (command);
@@ -1072,7 +1047,7 @@ inline GtkWidget *scale_pixbuf (GdkPixbuf *pixbuf, GtkIconSize icon_size)
                                                      (height/ greatest) * pix_y,
                                                       GDK_INTERP_BILINEAR);
         GtkWidget *image = gtk_image_new_from_pixbuf (scaled);
-        g_object_unref (G_OBJECT (scaled));
+        g_object_unref (scaled);
 
         return image;
     }
@@ -1100,7 +1075,7 @@ GtkWidget *create_ui_pixmap (GtkWidget *unused, GnomeUIPixmapType pixmap_type, g
                 if (pixbuf != NULL)
                 {
                     pixmap = scale_pixbuf (pixbuf, icon_size);
-                    g_object_unref (G_OBJECT (pixbuf));
+                    g_object_unref (pixbuf);
                 }
             }
             break;
@@ -1118,14 +1093,14 @@ GtkWidget *create_ui_pixmap (GtkWidget *unused, GnomeUIPixmapType pixmap_type, g
             {
                 GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file (name, NULL);
                 pixmap = scale_pixbuf (pixbuf, icon_size);
-                g_object_unref (G_OBJECT (pixbuf));
+                g_object_unref (pixbuf);
                 g_free (name);
             }
             break;
 
         default:
             g_assert_not_reached ();
-            g_warning("Invalid pixmap_type %d", (int) pixmap_type);
+            g_warning ("Invalid pixmap_type %d", (int) pixmap_type);
     }
 
     return pixmap;
@@ -1189,7 +1164,7 @@ GList *file_list_to_uri_list (GList *files)
     for (; files; files = files->next)
     {
         GnomeCmdFile *f = GNOME_CMD_FILE (files->data);
-        GnomeVFSURI *uri = gnome_cmd_file_get_uri (f);
+        GnomeVFSURI *uri = f->get_uri();
 
         if (!uri)
             g_warning ("NULL uri!!!");
@@ -1234,7 +1209,7 @@ gboolean create_dir_if_needed (const gchar *dpath)
             }
         }
         else
-            g_warning(_("Couldn't read from the directory %s: %s"), dpath, strerror (errno));
+            g_warning (_("Couldn't read from the directory %s: %s"), dpath, strerror (errno));
 
         return FALSE;
     }
@@ -1244,22 +1219,6 @@ gboolean create_dir_if_needed (const gchar *dpath)
 }
 
 
-void edit_mimetypes (const gchar *mime_type, gboolean blocking)
-{
-    if (!mime_type)
-        mime_type = "";
-
-    gchar *arg = g_shell_quote (mime_type);
-    gchar *cmd = g_strdup_printf ("gnome-file-types-properties %s\n", arg);
-    g_free (arg);
-    if (blocking)
-        system (cmd);
-    else
-        run_command (cmd);
-    g_free (cmd);
-}
-
-
 void fix_uri (GnomeVFSURI *uri)
 {
 #ifdef FIX_PW_HACK
@@ -1308,7 +1267,7 @@ GList *patlist_new (const gchar *pattern_string)
 
 void patlist_free (GList *pattern_list)
 {
-    g_return_if_fail (pattern_list != NULL);
+    if (!pattern_list)  return;
 
     g_list_foreach (pattern_list, (GFunc) g_free, NULL);
     g_list_free (pattern_list);
@@ -1317,11 +1276,11 @@ void patlist_free (GList *pattern_list)
 
 gboolean patlist_matches (GList *pattern_list, const gchar *s)
 {
-    for (GList *tmp = pattern_list; tmp; tmp = tmp->next)
+    for (GList *i=pattern_list; i; i=i->next)
 #ifdef FNM_CASEFOLD
-        if (fnmatch ((gchar *) tmp->data, s, FNM_NOESCAPE|FNM_CASEFOLD) == 0)
+        if (fnmatch ((gchar *) i->data, s, FNM_NOESCAPE|FNM_CASEFOLD) == 0)
 #else
-        if (fnmatch ((gchar *) tmp->data, s, FNM_NOESCAPE) == 0)   // omit FNM_CASEFOLD as it is a GNU extension.
+        if (fnmatch ((gchar *) i->data, s, FNM_NOESCAPE) == 0)   // omit FNM_CASEFOLD as it is a GNU extension.
 #endif
             return TRUE;
 
@@ -1371,6 +1330,60 @@ void gnome_cmd_toggle_file_name_selection (GtkWidget *entry)
 }
 
 
+gboolean gnome_cmd_prepend_su_to_vector (int &argc, char **&argv)
+{
+    // sanity
+    if(!argv)
+        argc = 0;
+
+    char *su = NULL;
+    gboolean need_c = FALSE;
+
+    if ((su = g_find_program_in_path ("xdg-su")))
+       goto with_c_param;
+    if ((su = g_find_program_in_path ("gksu")))
+       goto without_c_param;
+    if ((su = g_find_program_in_path ("gnomesu")))
+       goto with_c_param;
+    if ((su = g_find_program_in_path ("beesu")))
+       goto without_c_param;
+    if ((su = g_find_program_in_path ("kdesu")))
+       goto without_c_param;
+
+    return FALSE;
+
+ with_c_param:
+
+   need_c = TRUE;
+
+ without_c_param:
+
+    char **su_argv = g_new0 (char *, 3);
+    int su_argc = 0;
+
+    su_argv[su_argc++] = su;
+    if (need_c)
+        su_argv[su_argc++] = g_strdup("-c");
+
+    // compute size if not given
+    if (argc < 0)
+        for (argc=0; argv[argc]; ++argc);
+
+    int real_argc = su_argc + argc;
+    char **real_argv = g_new0 (char *, real_argc+1);
+
+    g_memmove (real_argv, su_argv, su_argc*sizeof(char *));
+    g_memmove (real_argv+su_argc, argv, argc*sizeof(char *));
+
+    g_free (argv);
+
+    argv = real_argv;
+    argc = real_argc;
+
+    return TRUE;
+}
+
+
 int split(const string &s, vector<string> &coll, const char *sep)
 {
   coll.clear();
