@@ -29,6 +29,8 @@
 
 #include <stdio.h>
 
+#include <libgnome/gnome-help.h>
+
 #include "gnome-cmd-file.h"
 #include "gnome-cmd-types.h"
 #include "gnome-cmd-pixmap.h"
@@ -44,7 +46,6 @@ inline gboolean DEBUG_ENABLED (gchar flag)
 }
 
 void DEBUG (gchar flag, const gchar *fmt, ...);
-void warn_print (const gchar *fmt, ...);
 
 void gnome_cmd_error_message (const gchar *title, GError *error);
 
@@ -52,15 +53,16 @@ void run_command_indir (const gchar *command, const gchar *dir, gboolean term);
 
 inline void run_command (const gchar *command)
 {
-   GError *error = NULL;
+    GError *error = NULL;
 
-   DEBUG ('g', "running: %s\n", command);
+    DEBUG ('g', "running: %s\n", command);
 
-   if (!g_spawn_command_line_async (command, &error))
-       gnome_cmd_error_message (command, error);
+    if (!g_spawn_command_line_async (command, &error))
+        gnome_cmd_error_message (command, error);
 }
 
 const char **convert_varargs_to_name_array (va_list args);
+
 gint run_simple_dialog (GtkWidget *parent, gboolean ignore_close_box,
                         GtkMessageType msg_type,
                         const char *text, const char *title, gint def_response, ...);
@@ -177,7 +179,7 @@ inline gboolean state_is_ctrl_alt_shift (gint state)
 GList *strings_to_uris (gchar *data);
 
 GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri);
-const gchar *create_nice_size_str (GnomeVFSFileSize size);
+gchar *create_nice_size_str (GnomeVFSFileSize size);
 
 inline gchar *quote_if_needed (const gchar *in)
 {
@@ -186,11 +188,6 @@ inline gchar *quote_if_needed (const gchar *in)
 
 gchar *unquote_if_needed (const gchar *in);
 
-inline void stop_kp (GtkObject *obj)
-{
-    gtk_signal_emit_stop_by_name (obj, "key-press-event");
-}
-
 GList *string_history_add (GList *in, const gchar *value, guint maxsize);
 
 GtkWidget *create_styled_button (const gchar *text);
@@ -200,8 +197,15 @@ void set_cursor_busy_for_widget (GtkWidget *widget);
 
 inline void set_cursor_default_for_widget (GtkWidget *widget)
 {
+#if GTK_CHECK_VERSION (2, 14, 0)
+    GdkWindow *window = gtk_widget_get_window (widget);
+
+    if (window)
+        gdk_window_set_cursor (window, NULL);
+#else
     if (widget->window)
         gdk_window_set_cursor (widget->window, NULL);
+#endif
 }
 
 void set_cursor_busy ();
@@ -225,7 +229,6 @@ GList *file_list_to_uri_list (GList *files);
 GList *file_list_to_info_list (GList *files);
 
 gboolean create_dir_if_needed (const gchar *dpath);
-void edit_mimetypes (const gchar *mime_type, gboolean blocking);
 void fix_uri (GnomeVFSURI *uri);
 
 inline gboolean uri_is_valid (const gchar *uri)
@@ -251,20 +254,27 @@ gboolean patlist_matches (GList *pattern_list, const gchar *s);
 
 void gnome_cmd_toggle_file_name_selection (GtkWidget *entry);
 
-inline void gnome_cmd_show_message (GtkWindow *parent, std::string message, const gchar *secondary_text=NULL)
+gboolean gnome_cmd_prepend_su_to_vector (int &argc, char **&argv);
+
+
+inline gint gnome_cmd_prompt_message (GtkWindow *parent, GtkMessageType type, GtkButtonsType buttons, const gchar *message, const gchar *secondary_text=NULL)
 {
-    GtkWidget *dlg = gtk_message_dialog_new (parent,
-                                             GTK_DIALOG_DESTROY_WITH_PARENT,
-                                             GTK_MESSAGE_ERROR,
-                                             GTK_BUTTONS_OK,
-                                             "%s",
-                                             message.c_str());
+    GtkWidget *dlg = gtk_message_dialog_new (parent, GTK_DIALOG_DESTROY_WITH_PARENT, type, buttons, "%s", message);
 
     if (secondary_text)
         gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dlg), "%s", secondary_text);
 
-    gtk_dialog_run (GTK_DIALOG (dlg));
+    gint result = gtk_dialog_run (GTK_DIALOG (dlg));
+
     gtk_widget_destroy (dlg);
+
+    return result;
+}
+
+
+inline void gnome_cmd_show_message (GtkWindow *parent, std::string message, const gchar *secondary_text=NULL)
+{
+    gnome_cmd_prompt_message (parent, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, message.c_str(), secondary_text);
 }
 
 
@@ -281,7 +291,7 @@ inline void gnome_cmd_help_display (const gchar *file_name, const gchar *link_id
 
 inline void gnome_cmd_error_message (const gchar *title, GError *error)
 {
-    gnome_cmd_show_message (NULL, title, error->message);
+    gnome_cmd_prompt_message (NULL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, title, error->message);
     g_error_free (error);
 }
 
